/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "HAN_Bus_Slave.h"
#include "HAN_Bus_Slave_UART.h"
#include "HAN_Bus_Slave_Control_Reg.h"
#include "HAN_Bus_Slave_Timer.h"
#include "HAN_Bus_Slave_TX_Int.h"
#include "HAN_Bus_Slave_RX_Int.h"
#include "HAN_Bus_Slave_Timeout_Int.h"

#define HAN_Bus_Slave_LINK_LED_ON_PORT_0()   {HAN_Bus_Slave_control_byte |=      1; HAN_Bus_Slave_Control_Reg_Write(HAN_Bus_Slave_control_byte);}
#define HAN_Bus_Slave_LINK_LED_OFF_PORT_0()  {HAN_Bus_Slave_control_byte &= 0xFF-1; HAN_Bus_Slave_Control_Reg_Write(HAN_Bus_Slave_control_byte);}

#define HAN_Bus_Slave_OPEN_PORT_1()          {HAN_Bus_Slave_control_byte |=      2; HAN_Bus_Slave_Control_Reg_Write(HAN_Bus_Slave_control_byte);}
#define HAN_Bus_Slave_CLOSE_PORT_1()         {HAN_Bus_Slave_control_byte &= 0xFF-2; HAN_Bus_Slave_Control_Reg_Write(HAN_Bus_Slave_control_byte);}

#define HAN_Bus_Slave_OPEN_PORT_2()          {HAN_Bus_Slave_control_byte |=      4; HAN_Bus_Slave_Control_Reg_Write(HAN_Bus_Slave_control_byte);}
#define HAN_Bus_Slave_CLOSE_PORT_2()         {HAN_Bus_Slave_control_byte &= 0xFF-4; HAN_Bus_Slave_Control_Reg_Write(HAN_Bus_Slave_control_byte);}

#define HAN_Bus_Slave_RECONNECT_PORT_0()     {HAN_Bus_Slave_control_byte |=      8; HAN_Bus_Slave_Control_Reg_Write(HAN_Bus_Slave_control_byte);}
#define HAN_Bus_Slave_LOOPBACK_PORT_0()      {HAN_Bus_Slave_control_byte &= 0xFF-8; HAN_Bus_Slave_Control_Reg_Write(HAN_Bus_Slave_control_byte);}

#define HAN_Bus_Slave_START_TIMEOUT_TIMER()  {HAN_Bus_Slave_Timer_WritePeriod(32000);}

unsigned char  HAN_Bus_Slave_message_buffer[256];
unsigned char* HAN_Bus_Slave_message_buffer_head;
unsigned char* HAN_Bus_Slave_message_buffer_tail;
unsigned int   HAN_Bus_Slave_buffer_length = 0;
unsigned char  HAN_Bus_Slave_control_byte  = 0;
unsigned char  HAN_Bus_Slave_flags         = 0;

#define FLAGS_PORT_1_FOUND_SLAVE        1
#define FLAGS_PORT_2_FOUND_SLAVE        2


#define STATE_WAITING_MESSAGE_START     0
#define STATE_QUERYING_PORT_1           1
#define STATE_QUERYING_PORT_2           2

unsigned char HAN_Bus_Slave_state = STATE_WAITING_MESSAGE_START;

#define TOKEN_PORT_QUERY            0xAA
#define TOKEN_PORT_QUERY_REPLY      0xBB
#define TOKEN_PORT_QUERY_TIMEOUT    0x11        // This is not a real token. It's just a value that's use to signal to the port
                                                // query state machine that a timeout happened

#define HAN_Bus_Slave_SET_FLAG(f)    {HAN_Bus_Slave_flags |=      f;}
#define HAN_Bus_Slave_CLEAR_FLAG(f)  {HAN_Bus_Slave_flags &= 0xff-f;}
#define HAN_Bus_Slave_FLAG_IS_SET(f) (HAN_Bus_Slave_flags&f)

void HAN_Bus_Slave_Handle_State_Waiting_Message_Start(unsigned char c)
{
    switch (c)
    {
        case TOKEN_PORT_QUERY:
            HAN_Bus_Slave_LINK_LED_ON_PORT_0();
            HAN_Bus_Slave_CLOSE_PORT_1();
            HAN_Bus_Slave_CLOSE_PORT_2();
            HAN_Bus_Slave_UART_PutChar(TOKEN_PORT_QUERY_REPLY);
            CyDelayUs(3);                                               // Wait until token is sent back upstream
            
            HAN_Bus_Slave_OPEN_PORT_1();                             // Now send a token to Port 1
            HAN_Bus_Slave_LOOPBACK_PORT_0();                         // and make sure any reply comes back to us, not back upstream
            HAN_Bus_Slave_UART_PutChar(TOKEN_PORT_QUERY);
            HAN_Bus_Slave_state = STATE_QUERYING_PORT_1;
            HAN_Bus_Slave_START_TIMEOUT_TIMER();
            break;
    }
}


void HAN_Bus_Slave_Handle_State_Querying_Port_1(unsigned char c)
{
    switch (c)
    {
        case TOKEN_PORT_QUERY:                                  // Success!   We got a reply on Port 1.
            HAN_Bus_Slave_SET_FLAG(FLAGS_PORT_1_FOUND_SLAVE);
            break;
        
        default:                                                // Strange!   We got a wrong reply on port 1.
            HAN_Bus_Slave_CLEAR_FLAG(FLAGS_PORT_1_FOUND_SLAVE);
            break;
    }        

    HAN_Bus_Slave_CLOSE_PORT_1();                            // Now send a token to Port 2
    HAN_Bus_Slave_OPEN_PORT_2();                             // Now send a token to Port 2
    HAN_Bus_Slave_LOOPBACK_PORT_0();                         // and make sure any reply comes back to us, not back upstream
    HAN_Bus_Slave_UART_PutChar(TOKEN_PORT_QUERY);
    HAN_Bus_Slave_state = STATE_QUERYING_PORT_2;
    HAN_Bus_Slave_START_TIMEOUT_TIMER();
}



void HAN_Bus_Slave_Handle_State_Querying_Port_2(unsigned char c)
{
    switch (c)
    {
        case TOKEN_PORT_QUERY:                                  // Success!   We got a reply on Port 2.
            HAN_Bus_Slave_SET_FLAG(FLAGS_PORT_2_FOUND_SLAVE);
            break;
        
        default:                                                // Strange!   We got a wrong reply on port 2. (or it was a timeout)
            HAN_Bus_Slave_CLEAR_FLAG(FLAGS_PORT_2_FOUND_SLAVE);
            break;
    }
    
    HAN_Bus_Slave_CLOSE_PORT_2();                                // Now Ports 1 and 2 are closed
    
    if (HAN_Bus_Slave_FLAG_IS_SET(FLAGS_PORT_1_FOUND_SLAVE))     // Re-open Port 1 if a slave was found there
    {
        HAN_Bus_Slave_OPEN_PORT_1();                             
    }

    if (HAN_Bus_Slave_FLAG_IS_SET(FLAGS_PORT_2_FOUND_SLAVE))     // Re-open Port 1 if a slave was found there
    {
        HAN_Bus_Slave_OPEN_PORT_2();                             
    }
    
    HAN_Bus_Slave_RECONNECT_PORT_0();
    HAN_Bus_Slave_state = STATE_WAITING_MESSAGE_START;
}


void HAN_Bus_Slave_Spoof_Byte_Received(unsigned char c)
{
    HAN_Bus_Slave_Handle_State_Waiting_Message_Start(c);
}


CY_ISR(HAN_Bus_Slave_TX_Int_Handler)
{
    //HAN_Bus_Slave_TX_Int_Clear_Pending();
    //HAN_Bus_Slave_Handle_State_Waiting_Message_Start(c);
}

CY_ISR(HAN_Bus_Slave_RX_Int_Handler)
{
    //HAN_Bus_Slave_RX_Int_Clear_Pending();
    
    unsigned char c = HAN_Bus_Slave_UART_GetChar();
    
    switch(HAN_Bus_Slave_state)
    {
        case STATE_WAITING_MESSAGE_START:
            HAN_Bus_Slave_Handle_State_Waiting_Message_Start(c);
            break;

        case STATE_QUERYING_PORT_1:
            HAN_Bus_Slave_Handle_State_Querying_Port_1(c);
            break;

        case STATE_QUERYING_PORT_2:
            HAN_Bus_Slave_Handle_State_Querying_Port_2(c);
            break;
    }
}


CY_ISR(HAN_Bus_Slave_Timeout_Int_Handler)
{
    HAN_Bus_Slave_Timer_ClearInterrupt(HAN_Bus_Slave_Timer_INTR_MASK_TC);
    
    switch(HAN_Bus_Slave_state)
    {
        case STATE_WAITING_MESSAGE_START:
            // Do nothing
            break;
        
        case STATE_QUERYING_PORT_1:
            HAN_Bus_Slave_Handle_State_Querying_Port_1(TOKEN_PORT_QUERY_TIMEOUT);
            break;

        case STATE_QUERYING_PORT_2:
            HAN_Bus_Slave_Handle_State_Querying_Port_2(TOKEN_PORT_QUERY_TIMEOUT);
            break;
        }
}

void Test()
{
    unsigned char i = 0;
  
    /*
    while(1)
    {
        HAN_Bus_Slave_UART_PutChar(i++);
        CyDelayUs(300);
    }
    */
    
    HAN_Bus_Slave_OPEN_PORT_1();
    while(1)
    {
        HAN_Bus_Slave_UART_PutString("Hello");
        CyDelay(5);
    }
}



void HAN_Bus_Slave_Start()
{
    
    HAN_Bus_Slave_message_buffer_head = HAN_Bus_Slave_message_buffer;
    HAN_Bus_Slave_message_buffer_tail = HAN_Bus_Slave_message_buffer;
    HAN_Bus_Slave_buffer_length       = 0;
    HAN_Bus_Slave_RECONNECT_PORT_0();
    HAN_Bus_Slave_CLOSE_PORT_1();
    HAN_Bus_Slave_CLOSE_PORT_2();
    HAN_Bus_Slave_LINK_LED_OFF_PORT_0();
    HAN_Bus_Slave_UART_Start();
    CyDelay(20);
    
    HAN_Bus_Slave_Timer_Start();             // Start the Timeout Timer. It will run, and cause one Timeout signal.
                                                // But don't enable the interrupt yet, because we don't want this one.
    CyDelay(40);                                 // Wait for it to finish once
    HAN_Bus_Slave_TX_Int_StartEx(HAN_Bus_Slave_TX_Int_Handler);                        // Now enable the interrupt, so we can use it again later.
    HAN_Bus_Slave_RX_Int_StartEx(HAN_Bus_Slave_RX_Int_Handler);                        // Now enable the interrupt, so we can use it again later.
    HAN_Bus_Slave_Timeout_Int_StartEx(HAN_Bus_Slave_Timeout_Int_Handler);                        // Now enable the interrupt, so we can use it again later.

    //Test();
}






/* [] END OF FILE */
