/*******************************************************************************
* File Name: HAN_Bus_Slave_UART_PM.c
* Version 2.50
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "HAN_Bus_Slave_UART.h"


/***************************************
* Local data allocation
***************************************/

static HAN_Bus_Slave_UART_BACKUP_STRUCT  HAN_Bus_Slave_UART_backup =
{
    /* enableState - disabled */
    0u,
};



/*******************************************************************************
* Function Name: HAN_Bus_Slave_UART_SaveConfig
********************************************************************************
*
* Summary:
*  This function saves the component nonretention control register.
*  Does not save the FIFO which is a set of nonretention registers.
*  This function is called by the HAN_Bus_Slave_UART_Sleep() function.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  HAN_Bus_Slave_UART_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void HAN_Bus_Slave_UART_SaveConfig(void)
{
    #if(HAN_Bus_Slave_UART_CONTROL_REG_REMOVED == 0u)
        HAN_Bus_Slave_UART_backup.cr = HAN_Bus_Slave_UART_CONTROL_REG;
    #endif /* End HAN_Bus_Slave_UART_CONTROL_REG_REMOVED */
}


/*******************************************************************************
* Function Name: HAN_Bus_Slave_UART_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the nonretention control register except FIFO.
*  Does not restore the FIFO which is a set of nonretention registers.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  HAN_Bus_Slave_UART_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
* Notes:
*  If this function is called without calling HAN_Bus_Slave_UART_SaveConfig() 
*  first, the data loaded may be incorrect.
*
*******************************************************************************/
void HAN_Bus_Slave_UART_RestoreConfig(void)
{
    #if(HAN_Bus_Slave_UART_CONTROL_REG_REMOVED == 0u)
        HAN_Bus_Slave_UART_CONTROL_REG = HAN_Bus_Slave_UART_backup.cr;
    #endif /* End HAN_Bus_Slave_UART_CONTROL_REG_REMOVED */
}


/*******************************************************************************
* Function Name: HAN_Bus_Slave_UART_Sleep
********************************************************************************
*
* Summary:
*  This is the preferred API to prepare the component for sleep. 
*  The HAN_Bus_Slave_UART_Sleep() API saves the current component state. Then it
*  calls the HAN_Bus_Slave_UART_Stop() function and calls 
*  HAN_Bus_Slave_UART_SaveConfig() to save the hardware configuration.
*  Call the HAN_Bus_Slave_UART_Sleep() function before calling the CyPmSleep() 
*  or the CyPmHibernate() function. 
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  HAN_Bus_Slave_UART_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void HAN_Bus_Slave_UART_Sleep(void)
{
    #if(HAN_Bus_Slave_UART_RX_ENABLED || HAN_Bus_Slave_UART_HD_ENABLED)
        if((HAN_Bus_Slave_UART_RXSTATUS_ACTL_REG  & HAN_Bus_Slave_UART_INT_ENABLE) != 0u)
        {
            HAN_Bus_Slave_UART_backup.enableState = 1u;
        }
        else
        {
            HAN_Bus_Slave_UART_backup.enableState = 0u;
        }
    #else
        if((HAN_Bus_Slave_UART_TXSTATUS_ACTL_REG  & HAN_Bus_Slave_UART_INT_ENABLE) !=0u)
        {
            HAN_Bus_Slave_UART_backup.enableState = 1u;
        }
        else
        {
            HAN_Bus_Slave_UART_backup.enableState = 0u;
        }
    #endif /* End HAN_Bus_Slave_UART_RX_ENABLED || HAN_Bus_Slave_UART_HD_ENABLED*/

    HAN_Bus_Slave_UART_Stop();
    HAN_Bus_Slave_UART_SaveConfig();
}


/*******************************************************************************
* Function Name: HAN_Bus_Slave_UART_Wakeup
********************************************************************************
*
* Summary:
*  This is the preferred API to restore the component to the state when 
*  HAN_Bus_Slave_UART_Sleep() was called. The HAN_Bus_Slave_UART_Wakeup() function
*  calls the HAN_Bus_Slave_UART_RestoreConfig() function to restore the 
*  configuration. If the component was enabled before the 
*  HAN_Bus_Slave_UART_Sleep() function was called, the HAN_Bus_Slave_UART_Wakeup()
*  function will also re-enable the component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  HAN_Bus_Slave_UART_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void HAN_Bus_Slave_UART_Wakeup(void)
{
    HAN_Bus_Slave_UART_RestoreConfig();
    #if( (HAN_Bus_Slave_UART_RX_ENABLED) || (HAN_Bus_Slave_UART_HD_ENABLED) )
        HAN_Bus_Slave_UART_ClearRxBuffer();
    #endif /* End (HAN_Bus_Slave_UART_RX_ENABLED) || (HAN_Bus_Slave_UART_HD_ENABLED) */
    #if(HAN_Bus_Slave_UART_TX_ENABLED || HAN_Bus_Slave_UART_HD_ENABLED)
        HAN_Bus_Slave_UART_ClearTxBuffer();
    #endif /* End HAN_Bus_Slave_UART_TX_ENABLED || HAN_Bus_Slave_UART_HD_ENABLED */

    if(HAN_Bus_Slave_UART_backup.enableState != 0u)
    {
        HAN_Bus_Slave_UART_Enable();
    }
}


/* [] END OF FILE */
