/*******************************************************************************
* File Name: Han_Bus_Slave_Diff_Comp_0.h
* Version 1.20
*
* Description:
*  This file contains the function prototypes and constants used in
*  the Analog Comparator User Module.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_COMPARATOR_Han_Bus_Slave_Diff_Comp_0_H)
#define CY_COMPARATOR_Han_Bus_Slave_Diff_Comp_0_H

#include "cytypes.h"
#include "CyLib.h"
#include "cyfitter.h"


/***************************************
*       Type Definitions
***************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} Han_Bus_Slave_Diff_Comp_0_BACKUP_STRUCT;


/**************************************
*        Function Prototypes
**************************************/
void    Han_Bus_Slave_Diff_Comp_0_Init(void);
void    Han_Bus_Slave_Diff_Comp_0_Enable(void);
void    Han_Bus_Slave_Diff_Comp_0_Start(void);
void    Han_Bus_Slave_Diff_Comp_0_Stop(void);
void    Han_Bus_Slave_Diff_Comp_0_SetSpeed(uint32 speed);
uint32  Han_Bus_Slave_Diff_Comp_0_ZeroCal(void);
void    Han_Bus_Slave_Diff_Comp_0_LoadTrim(uint32 trimVal);
void    Han_Bus_Slave_Diff_Comp_0_Sleep(void);
void    Han_Bus_Slave_Diff_Comp_0_Wakeup(void);
void    Han_Bus_Slave_Diff_Comp_0_SaveConfig(void);
void    Han_Bus_Slave_Diff_Comp_0_RestoreConfig(void);
uint32  Han_Bus_Slave_Diff_Comp_0_GetCompare(void);
uint32  Han_Bus_Slave_Diff_Comp_0_GetInterruptSource(void);
void    Han_Bus_Slave_Diff_Comp_0_ClearInterrupt(uint32 interruptMask);
void    Han_Bus_Slave_Diff_Comp_0_SetInterrupt(uint32 interruptMask);
void    Han_Bus_Slave_Diff_Comp_0_SetInterruptMask(uint32 interruptMask);
uint32  Han_Bus_Slave_Diff_Comp_0_GetInterruptMask(void);
uint32  Han_Bus_Slave_Diff_Comp_0_GetInterruptSourceMasked(void);
void    Han_Bus_Slave_Diff_Comp_0_SetInterruptMode(uint32 mode);
void    Han_Bus_Slave_Diff_Comp_0_DisableInterruptOutput(void);

#define Han_Bus_Slave_Diff_Comp_0_EnableInterruptOutput(void)     Han_Bus_Slave_Diff_Comp_0_SetInterruptMask(Han_Bus_Slave_Diff_Comp_0_GetInterruptMask() | Han_Bus_Slave_Diff_Comp_0_INTR_MASK)
#define Han_Bus_Slave_Diff_Comp_0_GetInterruptOutputStatus(void)  ((0u == (Han_Bus_Slave_Diff_Comp_0_GetInterruptSourceMasked() & Han_Bus_Slave_Diff_Comp_0_INTR_MASKED)) ? 0u : 1u)
#define Han_Bus_Slave_Diff_Comp_0_ClearInterruptOutput(void)      Han_Bus_Slave_Diff_Comp_0_ClearInterrupt(Han_Bus_Slave_Diff_Comp_0_INTR)
#define Han_Bus_Slave_Diff_Comp_0_SetInterruptOutput(void)        Han_Bus_Slave_Diff_Comp_0_SetInterrupt(Han_Bus_Slave_Diff_Comp_0_INTR_MASK)

/**************************************
*           API Constants
**************************************/

/* Power constants for SetSpeed() function */
#define Han_Bus_Slave_Diff_Comp_0_SLOW_SPEED     (0x01u)
#define Han_Bus_Slave_Diff_Comp_0_MED_SPEED      (0x02u)
#define Han_Bus_Slave_Diff_Comp_0_HIGH_SPEED     (0x03u)

/* Trim defines for ZeroCal() function */
#define Han_Bus_Slave_Diff_Comp_0_COMP_TRIM_SIGN_SHIFT   (5u)
#define Han_Bus_Slave_Diff_Comp_0_COMP_TRIM_MAX_VALUE    (32u)
#define Han_Bus_Slave_Diff_Comp_0_COMP_CALIBRATION_DELAY (10u)

/* Constants for Han_Bus_Slave_Diff_Comp_0_SetInterruptMode(), mode parameter */
#define Han_Bus_Slave_Diff_Comp_0_INTR_DISABLE       (0x00u)
#define Han_Bus_Slave_Diff_Comp_0_INTR_RISING        (0x01u)
#define Han_Bus_Slave_Diff_Comp_0_INTR_FALLING       (0x02u)
#define Han_Bus_Slave_Diff_Comp_0_INTR_BOTH          (0x03u)

/* Constants for Han_Bus_Slave_Diff_Comp_0_GetInterruptSource() and 
* Han_Bus_Slave_Diff_Comp_0_ClearInterrupt(), interruptMask parameter 
*/
#define Han_Bus_Slave_Diff_Comp_0_INTR_SHIFT         (Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__INTR_SHIFT)
#define Han_Bus_Slave_Diff_Comp_0_INTR               ((uint32)0x01u << Han_Bus_Slave_Diff_Comp_0_INTR_SHIFT)

/* Constants for Han_Bus_Slave_Diff_Comp_0_SetInterrupt(), interruptMask parameter */
#define Han_Bus_Slave_Diff_Comp_0_INTR_SET_SHIFT     (Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__INTR_SET_SHIFT)
#define Han_Bus_Slave_Diff_Comp_0_INTR_SET           ((uint32)0x01u << Han_Bus_Slave_Diff_Comp_0_INTR_SHIFT)

/* Constants for Han_Bus_Slave_Diff_Comp_0_GetInterruptMask() and 
* Han_Bus_Slave_Diff_Comp_0_SetInterruptMask(), interruptMask parameter 
*/
#define Han_Bus_Slave_Diff_Comp_0_INTR_MASK_SHIFT    (Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__INTR_MASK_SHIFT)
#define Han_Bus_Slave_Diff_Comp_0_INTR_MASK          ((uint32)0x01u << Han_Bus_Slave_Diff_Comp_0_INTR_MASK_SHIFT)

/* Constants for Han_Bus_Slave_Diff_Comp_0_GetInterruptSourceMasked() */ 
#define Han_Bus_Slave_Diff_Comp_0_INTR_MASKED_SHIFT  (Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__INTR_MASKED_SHIFT)
#define Han_Bus_Slave_Diff_Comp_0_INTR_MASKED        ((uint32)0x01u << Han_Bus_Slave_Diff_Comp_0_INTR_MASKED_SHIFT)


/***************************************
*   Initial Parameter Constants
****************************************/

#define Han_Bus_Slave_Diff_Comp_0_HYSTERESIS         (1u)
#define Han_Bus_Slave_Diff_Comp_0_POWER              (3u)
#define Han_Bus_Slave_Diff_Comp_0_DEEPSLEEP_SUPPORT  (0u)
#define Han_Bus_Slave_Diff_Comp_0_INTERRUPT_EN       (0u)
#define Han_Bus_Slave_Diff_Comp_0_INTERRUPT          (1u)


/***************************************
*    Variables with External Linkage
***************************************/

extern uint8  Han_Bus_Slave_Diff_Comp_0_initVar;


/**************************************
*             Registers
**************************************/

#ifdef CYIPBLOCK_m0s8pass4b_VERSION
    #define Han_Bus_Slave_Diff_Comp_0_CTB_CTRL_REG       (*(reg32 *) Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__CTB_CTB_CTRL)
    #define Han_Bus_Slave_Diff_Comp_0_CTB_CTRL_PTR       ( (reg32 *) Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__CTB_CTB_CTRL)
#else
    #define Han_Bus_Slave_Diff_Comp_0_CTB_CTRL_REG       (*(reg32 *) Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__CTBM_CTB_CTRL)
    #define Han_Bus_Slave_Diff_Comp_0_CTB_CTRL_PTR       ( (reg32 *) Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__CTBM_CTB_CTRL)
#endif /* CYIPBLOCK_m0s8pass4b_VERSION */

#define Han_Bus_Slave_Diff_Comp_0_OA_RES_CTRL_REG            (* (reg32 *) Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__OA_RES_CTRL)
#define Han_Bus_Slave_Diff_Comp_0_OA_RES_CTRL_PTR            (  (reg32 *) Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__OA_RES_CTRL)

#define Han_Bus_Slave_Diff_Comp_0_OA_COMP_STAT_REG           (* (reg32 *) Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__COMP_STAT)
#define Han_Bus_Slave_Diff_Comp_0_OA_COMP_STAT_PTR           (  (reg32 *) Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__COMP_STAT)

#define Han_Bus_Slave_Diff_Comp_0_OA_OFFSET_TRIM_REG         (* (reg32 *) Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__OA_OFFSET_TRIM)
#define Han_Bus_Slave_Diff_Comp_0_OA_OFFSET_TRIM_PTR         (  (reg32 *) Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__OA_OFFSET_TRIM)

#define Han_Bus_Slave_Diff_Comp_0_OA_SLOPE_OFFSET_TRIM_REG   (* (reg32 *) Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__OA_SLOPE_OFFSET_TRIM)
#define Han_Bus_Slave_Diff_Comp_0_OA_SLOPE_OFFSET_TRIM_PTR   (  (reg32 *) Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__OA_SLOPE_OFFSET_TRIM)

#define Han_Bus_Slave_Diff_Comp_0_OA_COMP_SHIFT              (Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__COMP_STAT_SHIFT)

#define Han_Bus_Slave_Diff_Comp_0_INTR_REG       (*(reg32 *)Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__INTR)
#define Han_Bus_Slave_Diff_Comp_0_INTR_PTR       ( (reg32 *)Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__INTR)

#define Han_Bus_Slave_Diff_Comp_0_INTR_SET_REG   (*(reg32 *)Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__INTR_SET)
#define Han_Bus_Slave_Diff_Comp_0_INTR_SET_PTR   ( (reg32 *)Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__INTR_SET)

#define Han_Bus_Slave_Diff_Comp_0_INTR_MASK_REG    (*(reg32 *)Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__INTR_MASK) 
#define Han_Bus_Slave_Diff_Comp_0_INTR_MASK_PTR    ( (reg32 *)Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__INTR_MASK) 

#define Han_Bus_Slave_Diff_Comp_0_INTR_MASKED_REG  (*(reg32 *)Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__INTR_MASKED) 
#define Han_Bus_Slave_Diff_Comp_0_INTR_MASKED_PTR  ( (reg32 *)Han_Bus_Slave_Diff_Comp_0_cy_psoc4_abuf__INTR_MASKED)

/***************************************
*        Registers Constants
***************************************/

/* Han_Bus_Slave_Diff_Comp_0_CTB_CTRL_REG */
#define Han_Bus_Slave_Diff_Comp_0_CTB_CTRL_DEEPSLEEP_ON_SHIFT    (30u)   /* [30] Selects behavior CTB IP in the DeepSleep power mode */
#define Han_Bus_Slave_Diff_Comp_0_CTB_CTRL_ENABLED_SHIFT         (31u)   /* [31] Enable of the CTB IP */

#define Han_Bus_Slave_Diff_Comp_0_CTB_CTRL_DEEPSLEEP_ON          ((uint32) 0x01u << Han_Bus_Slave_Diff_Comp_0_CTB_CTRL_DEEPSLEEP_ON_SHIFT)
#define Han_Bus_Slave_Diff_Comp_0_CTB_CTRL_ENABLED               ((uint32) 0x01u << Han_Bus_Slave_Diff_Comp_0_CTB_CTRL_ENABLED_SHIFT)

/* Han_Bus_Slave_Diff_Comp_0_OA_RES_CTRL_REG */
#define Han_Bus_Slave_Diff_Comp_0_OA_PWR_MODE_SHIFT          (0u)    /* [1:0]    Power level */
#define Han_Bus_Slave_Diff_Comp_0_OA_COMP_EN_SHIFT           (4u)    /* [4]      Comparator enable */
#define Han_Bus_Slave_Diff_Comp_0_OA_HYST_EN_SHIFT           (5u)    /* [5]      Hysteresis enable (10mV) */
#define Han_Bus_Slave_Diff_Comp_0_OA_BYPASS_DSI_SYNC_SHIFT   (6u)    /* [6]      Bypass comparator output synchronization for DSI (trigger) output */
#define Han_Bus_Slave_Diff_Comp_0_OA_COMPINT_SHIFT           (8u)    /* [9:8]    Sets Interrupt mode */
#define Han_Bus_Slave_Diff_Comp_0_OA_PUMP_EN_SHIFT           (11u)   /* [11]     Pump enable */

#define Han_Bus_Slave_Diff_Comp_0_OA_PWR_MODE                ((uint32) 0x02u << Han_Bus_Slave_Diff_Comp_0_OA_PWR_MODE_SHIFT)
#define Han_Bus_Slave_Diff_Comp_0_OA_PWR_MODE_MASK           ((uint32) 0x03u << Han_Bus_Slave_Diff_Comp_0_OA_PWR_MODE_SHIFT)
#define Han_Bus_Slave_Diff_Comp_0_OA_COMP_EN                 ((uint32) 0x01u << Han_Bus_Slave_Diff_Comp_0_OA_COMP_EN_SHIFT)
#define Han_Bus_Slave_Diff_Comp_0_OA_HYST_EN                 ((uint32) 0x01u << Han_Bus_Slave_Diff_Comp_0_OA_HYST_EN_SHIFT)
#define Han_Bus_Slave_Diff_Comp_0_OA_BYPASS_DSI_SYNC         ((uint32) 0x01u << Han_Bus_Slave_Diff_Comp_0_OA_BYPASS_DSI_SYNC_SHIFT)
#define Han_Bus_Slave_Diff_Comp_0_OA_COMPINT_MASK            ((uint32) 0x03u << Han_Bus_Slave_Diff_Comp_0_OA_COMPINT_SHIFT)
#define Han_Bus_Slave_Diff_Comp_0_OA_PUMP_EN                 ((uint32) 0x01u << Han_Bus_Slave_Diff_Comp_0_OA_PUMP_EN_SHIFT)


/***************************************
*       Init Macros Definitions
***************************************/

#define Han_Bus_Slave_Diff_Comp_0_GET_DEEPSLEEP_ON(deepSleep)    ((0u != (deepSleep)) ? (Han_Bus_Slave_Diff_Comp_0_CTB_CTRL_DEEPSLEEP_ON) : (0u))
#define Han_Bus_Slave_Diff_Comp_0_GET_OA_HYST_EN(hyst)           ((0u != (hyst)) ? (Han_Bus_Slave_Diff_Comp_0_OA_HYST_EN) : (0u))
#define Han_Bus_Slave_Diff_Comp_0_GET_OA_PWR_MODE(mode)          ((mode) & Han_Bus_Slave_Diff_Comp_0_OA_PWR_MODE_MASK)
#define Han_Bus_Slave_Diff_Comp_0_CHECK_PWR_MODE_OFF             (0u != (Han_Bus_Slave_Diff_Comp_0_OA_RES_CTRL_REG & \
                                                                Han_Bus_Slave_Diff_Comp_0_OA_PWR_MODE_MASK))
#define Han_Bus_Slave_Diff_Comp_0_GET_OA_COMPINT(intType)        ((uint32) ((((uint32)(intType) << Han_Bus_Slave_Diff_Comp_0_OA_COMPINT_SHIFT)) & \
                                                        Han_Bus_Slave_Diff_Comp_0_OA_COMPINT_MASK))

#define Han_Bus_Slave_Diff_Comp_0_GET_INTR_MASK(mask)            ((0u != (mask)) ? (Han_Bus_Slave_Diff_Comp_0_INTR_MASK) : (0u))

/* Returns true if component available in Deep Sleep power mode*/ 
#define Han_Bus_Slave_Diff_Comp_0_CHECK_DEEPSLEEP_SUPPORT        (0u != Han_Bus_Slave_Diff_Comp_0_DEEPSLEEP_SUPPORT) 

#define Han_Bus_Slave_Diff_Comp_0_DEFAULT_CTB_CTRL (Han_Bus_Slave_Diff_Comp_0_GET_DEEPSLEEP_ON(Han_Bus_Slave_Diff_Comp_0_DEEPSLEEP_SUPPORT) | \
                                           Han_Bus_Slave_Diff_Comp_0_CTB_CTRL_ENABLED)

#define Han_Bus_Slave_Diff_Comp_0_DEFAULT_OA_RES_CTRL (Han_Bus_Slave_Diff_Comp_0_OA_COMP_EN | \
                                              Han_Bus_Slave_Diff_Comp_0_GET_OA_HYST_EN(Han_Bus_Slave_Diff_Comp_0_HYSTERESIS)  | \
                                              Han_Bus_Slave_Diff_Comp_0_GET_OA_COMPINT(Han_Bus_Slave_Diff_Comp_0_INTERRUPT) |\
                                              Han_Bus_Slave_Diff_Comp_0_OA_BYPASS_DSI_SYNC)

#define Han_Bus_Slave_Diff_Comp_0_INTR_MASK_REG_DEFAULT  (Han_Bus_Slave_Diff_Comp_0_GET_INTR_MASK(Han_Bus_Slave_Diff_Comp_0_INTERRUPT_EN))


/***************************************
* The following code is DEPRECATED and 
* should not be used in new projects.
***************************************/

/* Power constants for SetSpeed() function */
#define Han_Bus_Slave_Diff_Comp_0_SLOWSPEED      (Han_Bus_Slave_Diff_Comp_0_SLOW_SPEED)
#define Han_Bus_Slave_Diff_Comp_0_MEDSPEED       (Han_Bus_Slave_Diff_Comp_0_MED_SPEED)
#define Han_Bus_Slave_Diff_Comp_0_HIGHSPEED      (Han_Bus_Slave_Diff_Comp_0_HIGH_SPEED)

#define Han_Bus_Slave_Diff_Comp_0_OA_CTRL_REG        (Han_Bus_Slave_Diff_Comp_0_OA_RES_CTRL_REG)
#define Han_Bus_Slave_Diff_Comp_0_OA_COMPSTAT_REG    (Han_Bus_Slave_Diff_Comp_0_OA_COMP_STAT_REG)
#define Han_Bus_Slave_Diff_Comp_0_OA_COMPSHIFT       (Han_Bus_Slave_Diff_Comp_0_OA_COMP_SHIFT)

#define Han_Bus_Slave_Diff_Comp_0_OA_CTB_EN_SHIFT    (Han_Bus_Slave_Diff_Comp_0_CTB_CTRL_ENABLED_SHIFT)
#define Han_Bus_Slave_Diff_Comp_0_OA_PWR_MODE_HIGH   (Han_Bus_Slave_Diff_Comp_0_HIGH_SPEED) 
#define Han_Bus_Slave_Diff_Comp_0_OA_BYPASS_SHIFT    (Han_Bus_Slave_Diff_Comp_0_OA_BYPASS_DSI_SYNC_SHIFT)

#endif /*  CY_COMPARATOR_Han_Bus_Slave_Diff_Comp_0_H */


/* [] END OF FILE */
