/***************************************************************************//**
* \file Han_Bus_Slave_Diff_UART_Debug.c
* \version 3.20
*
* \brief
*  This file provides the source code to the API for the SCB Component.
*
* Note:
*
*******************************************************************************
* \copyright
* Copyright 2013-2016, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "Han_Bus_Slave_Diff_UART_Debug_PVT.h"

#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_I2C_INC)
    #include "Han_Bus_Slave_Diff_UART_Debug_I2C_PVT.h"
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_I2C_INC) */

#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_EZI2C_INC)
    #include "Han_Bus_Slave_Diff_UART_Debug_EZI2C_PVT.h"
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_EZI2C_INC) */

#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_SPI_INC || Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UART_INC)
    #include "Han_Bus_Slave_Diff_UART_Debug_SPI_UART_PVT.h"
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_SPI_INC || Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UART_INC) */


/***************************************
*    Run Time Configuration Vars
***************************************/

/* Stores internal component configuration for Unconfigured mode */
#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Common configuration variables */
    uint8 Han_Bus_Slave_Diff_UART_Debug_scbMode = Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG;
    uint8 Han_Bus_Slave_Diff_UART_Debug_scbEnableWake;
    uint8 Han_Bus_Slave_Diff_UART_Debug_scbEnableIntr;

    /* I2C configuration variables */
    uint8 Han_Bus_Slave_Diff_UART_Debug_mode;
    uint8 Han_Bus_Slave_Diff_UART_Debug_acceptAddr;

    /* SPI/UART configuration variables */
    volatile uint8 * Han_Bus_Slave_Diff_UART_Debug_rxBuffer;
    uint8  Han_Bus_Slave_Diff_UART_Debug_rxDataBits;
    uint32 Han_Bus_Slave_Diff_UART_Debug_rxBufferSize;

    volatile uint8 * Han_Bus_Slave_Diff_UART_Debug_txBuffer;
    uint8  Han_Bus_Slave_Diff_UART_Debug_txDataBits;
    uint32 Han_Bus_Slave_Diff_UART_Debug_txBufferSize;

    /* EZI2C configuration variables */
    uint8 Han_Bus_Slave_Diff_UART_Debug_numberOfAddr;
    uint8 Han_Bus_Slave_Diff_UART_Debug_subAddrSize;
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*     Common SCB Vars
***************************************/
/**
* \addtogroup group_general
* \{
*/

/** Han_Bus_Slave_Diff_UART_Debug_initVar indicates whether the Han_Bus_Slave_Diff_UART_Debug 
*  component has been initialized. The variable is initialized to 0 
*  and set to 1 the first time SCB_Start() is called. This allows 
*  the component to restart without reinitialization after the first 
*  call to the Han_Bus_Slave_Diff_UART_Debug_Start() routine.
*
*  If re-initialization of the component is required, then the 
*  Han_Bus_Slave_Diff_UART_Debug_Init() function can be called before the 
*  Han_Bus_Slave_Diff_UART_Debug_Start() or Han_Bus_Slave_Diff_UART_Debug_Enable() function.
*/
uint8 Han_Bus_Slave_Diff_UART_Debug_initVar = 0u;


#if (! (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_I2C_CONST_CFG || \
        Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_EZI2C_CONST_CFG))
    /** This global variable stores TX interrupt sources after 
    * Han_Bus_Slave_Diff_UART_Debug_Stop() is called. Only these TX interrupt sources 
    * will be restored on a subsequent Han_Bus_Slave_Diff_UART_Debug_Enable() call.
    */
    uint16 Han_Bus_Slave_Diff_UART_Debug_IntrTxMask = 0u;
#endif /* (! (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_I2C_CONST_CFG || \
              Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_EZI2C_CONST_CFG)) */
/** \} globals */

#if (Han_Bus_Slave_Diff_UART_Debug_SCB_IRQ_INTERNAL)
#if !defined (CY_REMOVE_Han_Bus_Slave_Diff_UART_Debug_CUSTOM_INTR_HANDLER)
    void (*Han_Bus_Slave_Diff_UART_Debug_customIntrHandler)(void) = NULL;
#endif /* !defined (CY_REMOVE_Han_Bus_Slave_Diff_UART_Debug_CUSTOM_INTR_HANDLER) */
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_IRQ_INTERNAL) */


/***************************************
*    Private Function Prototypes
***************************************/

static void Han_Bus_Slave_Diff_UART_Debug_ScbEnableIntr(void);
static void Han_Bus_Slave_Diff_UART_Debug_ScbModeStop(void);
static void Han_Bus_Slave_Diff_UART_Debug_ScbModePostEnable(void);


/*******************************************************************************
* Function Name: Han_Bus_Slave_Diff_UART_Debug_Init
****************************************************************************//**
*
*  Initializes the Han_Bus_Slave_Diff_UART_Debug component to operate in one of the selected
*  configurations: I2C, SPI, UART or EZI2C.
*  When the configuration is set to "Unconfigured SCB", this function does
*  not do any initialization. Use mode-specific initialization APIs instead:
*  Han_Bus_Slave_Diff_UART_Debug_I2CInit, Han_Bus_Slave_Diff_UART_Debug_SpiInit, 
*  Han_Bus_Slave_Diff_UART_Debug_UartInit or Han_Bus_Slave_Diff_UART_Debug_EzI2CInit.
*
*******************************************************************************/
void Han_Bus_Slave_Diff_UART_Debug_Init(void)
{
#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG)
    if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_RUNTM_CFG)
    {
        Han_Bus_Slave_Diff_UART_Debug_initVar = 0u;
    }
    else
    {
        /* Initialization was done before this function call */
    }

#elif (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_I2C_CONST_CFG)
    Han_Bus_Slave_Diff_UART_Debug_I2CInit();

#elif (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_SPI_CONST_CFG)
    Han_Bus_Slave_Diff_UART_Debug_SpiInit();

#elif (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UART_CONST_CFG)
    Han_Bus_Slave_Diff_UART_Debug_UartInit();

#elif (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_EZI2C_CONST_CFG)
    Han_Bus_Slave_Diff_UART_Debug_EzI2CInit();

#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: Han_Bus_Slave_Diff_UART_Debug_Enable
****************************************************************************//**
*
*  Enables Han_Bus_Slave_Diff_UART_Debug component operation: activates the hardware and 
*  internal interrupt. It also restores TX interrupt sources disabled after the 
*  Han_Bus_Slave_Diff_UART_Debug_Stop() function was called (note that level-triggered TX 
*  interrupt sources remain disabled to not cause code lock-up).
*  For I2C and EZI2C modes the interrupt is internal and mandatory for 
*  operation. For SPI and UART modes the interrupt can be configured as none, 
*  internal or external.
*  The Han_Bus_Slave_Diff_UART_Debug configuration should be not changed when the component
*  is enabled. Any configuration changes should be made after disabling the 
*  component.
*  When configuration is set to Unconfigured Han_Bus_Slave_Diff_UART_Debug, the component 
*  must first be initialized to operate in one of the following configurations: 
*  I2C, SPI, UART or EZ I2C, using the mode-specific initialization API. 
*  Otherwise this function does not enable the component.
*
*******************************************************************************/
void Han_Bus_Slave_Diff_UART_Debug_Enable(void)
{
#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Enable SCB block, only if it is already configured */
    if (!Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_RUNTM_CFG)
    {
        Han_Bus_Slave_Diff_UART_Debug_CTRL_REG |= Han_Bus_Slave_Diff_UART_Debug_CTRL_ENABLED;

        Han_Bus_Slave_Diff_UART_Debug_ScbEnableIntr();

        /* Call PostEnable function specific to current operation mode */
        Han_Bus_Slave_Diff_UART_Debug_ScbModePostEnable();
    }
#else
    Han_Bus_Slave_Diff_UART_Debug_CTRL_REG |= Han_Bus_Slave_Diff_UART_Debug_CTRL_ENABLED;

    Han_Bus_Slave_Diff_UART_Debug_ScbEnableIntr();

    /* Call PostEnable function specific to current operation mode */
    Han_Bus_Slave_Diff_UART_Debug_ScbModePostEnable();
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: Han_Bus_Slave_Diff_UART_Debug_Start
****************************************************************************//**
*
*  Invokes Han_Bus_Slave_Diff_UART_Debug_Init() and Han_Bus_Slave_Diff_UART_Debug_Enable().
*  After this function call, the component is enabled and ready for operation.
*  When configuration is set to "Unconfigured SCB", the component must first be
*  initialized to operate in one of the following configurations: I2C, SPI, UART
*  or EZI2C. Otherwise this function does not enable the component.
*
* \globalvars
*  Han_Bus_Slave_Diff_UART_Debug_initVar - used to check initial configuration, modified
*  on first function call.
*
*******************************************************************************/
void Han_Bus_Slave_Diff_UART_Debug_Start(void)
{
    if (0u == Han_Bus_Slave_Diff_UART_Debug_initVar)
    {
        Han_Bus_Slave_Diff_UART_Debug_Init();
        Han_Bus_Slave_Diff_UART_Debug_initVar = 1u; /* Component was initialized */
    }

    Han_Bus_Slave_Diff_UART_Debug_Enable();
}


/*******************************************************************************
* Function Name: Han_Bus_Slave_Diff_UART_Debug_Stop
****************************************************************************//**
*
*  Disables the Han_Bus_Slave_Diff_UART_Debug component: disable the hardware and internal 
*  interrupt. It also disables all TX interrupt sources so as not to cause an 
*  unexpected interrupt trigger because after the component is enabled, the 
*  TX FIFO is empty.
*  Refer to the function Han_Bus_Slave_Diff_UART_Debug_Enable() for the interrupt 
*  configuration details.
*  This function disables the SCB component without checking to see if 
*  communication is in progress. Before calling this function it may be 
*  necessary to check the status of communication to make sure communication 
*  is complete. If this is not done then communication could be stopped mid 
*  byte and corrupted data could result.
*
*******************************************************************************/
void Han_Bus_Slave_Diff_UART_Debug_Stop(void)
{
#if (Han_Bus_Slave_Diff_UART_Debug_SCB_IRQ_INTERNAL)
    Han_Bus_Slave_Diff_UART_Debug_DisableInt();
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_IRQ_INTERNAL) */

    /* Call Stop function specific to current operation mode */
    Han_Bus_Slave_Diff_UART_Debug_ScbModeStop();

    /* Disable SCB IP */
    Han_Bus_Slave_Diff_UART_Debug_CTRL_REG &= (uint32) ~Han_Bus_Slave_Diff_UART_Debug_CTRL_ENABLED;

    /* Disable all TX interrupt sources so as not to cause an unexpected
    * interrupt trigger after the component will be enabled because the 
    * TX FIFO is empty.
    * For SCB IP v0, it is critical as it does not mask-out interrupt
    * sources when it is disabled. This can cause a code lock-up in the
    * interrupt handler because TX FIFO cannot be loaded after the block
    * is disabled.
    */
    Han_Bus_Slave_Diff_UART_Debug_SetTxInterruptMode(Han_Bus_Slave_Diff_UART_Debug_NO_INTR_SOURCES);

#if (Han_Bus_Slave_Diff_UART_Debug_SCB_IRQ_INTERNAL)
    Han_Bus_Slave_Diff_UART_Debug_ClearPendingInt();
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_IRQ_INTERNAL) */
}


/*******************************************************************************
* Function Name: Han_Bus_Slave_Diff_UART_Debug_SetRxFifoLevel
****************************************************************************//**
*
*  Sets level in the RX FIFO to generate a RX level interrupt.
*  When the RX FIFO has more entries than the RX FIFO level an RX level
*  interrupt request is generated.
*
*  \param level: Level in the RX FIFO to generate RX level interrupt.
*   The range of valid level values is between 0 and RX FIFO depth - 1.
*
*******************************************************************************/
void Han_Bus_Slave_Diff_UART_Debug_SetRxFifoLevel(uint32 level)
{
    uint32 rxFifoCtrl;

    rxFifoCtrl = Han_Bus_Slave_Diff_UART_Debug_RX_FIFO_CTRL_REG;

    rxFifoCtrl &= ((uint32) ~Han_Bus_Slave_Diff_UART_Debug_RX_FIFO_CTRL_TRIGGER_LEVEL_MASK); /* Clear level mask bits */
    rxFifoCtrl |= ((uint32) (Han_Bus_Slave_Diff_UART_Debug_RX_FIFO_CTRL_TRIGGER_LEVEL_MASK & level));

    Han_Bus_Slave_Diff_UART_Debug_RX_FIFO_CTRL_REG = rxFifoCtrl;
}


/*******************************************************************************
* Function Name: Han_Bus_Slave_Diff_UART_Debug_SetTxFifoLevel
****************************************************************************//**
*
*  Sets level in the TX FIFO to generate a TX level interrupt.
*  When the TX FIFO has less entries than the TX FIFO level an TX level
*  interrupt request is generated.
*
*  \param level: Level in the TX FIFO to generate TX level interrupt.
*   The range of valid level values is between 0 and TX FIFO depth - 1.
*
*******************************************************************************/
void Han_Bus_Slave_Diff_UART_Debug_SetTxFifoLevel(uint32 level)
{
    uint32 txFifoCtrl;

    txFifoCtrl = Han_Bus_Slave_Diff_UART_Debug_TX_FIFO_CTRL_REG;

    txFifoCtrl &= ((uint32) ~Han_Bus_Slave_Diff_UART_Debug_TX_FIFO_CTRL_TRIGGER_LEVEL_MASK); /* Clear level mask bits */
    txFifoCtrl |= ((uint32) (Han_Bus_Slave_Diff_UART_Debug_TX_FIFO_CTRL_TRIGGER_LEVEL_MASK & level));

    Han_Bus_Slave_Diff_UART_Debug_TX_FIFO_CTRL_REG = txFifoCtrl;
}


#if (Han_Bus_Slave_Diff_UART_Debug_SCB_IRQ_INTERNAL)
    /*******************************************************************************
    * Function Name: Han_Bus_Slave_Diff_UART_Debug_SetCustomInterruptHandler
    ****************************************************************************//**
    *
    *  Registers a function to be called by the internal interrupt handler.
    *  First the function that is registered is called, then the internal interrupt
    *  handler performs any operation such as software buffer management functions
    *  before the interrupt returns.  It is the user's responsibility not to break
    *  the software buffer operations. Only one custom handler is supported, which
    *  is the function provided by the most recent call.
    *  At the initialization time no custom handler is registered.
    *
    *  \param func: Pointer to the function to register.
    *        The value NULL indicates to remove the current custom interrupt
    *        handler.
    *
    *******************************************************************************/
    void Han_Bus_Slave_Diff_UART_Debug_SetCustomInterruptHandler(void (*func)(void))
    {
    #if !defined (CY_REMOVE_Han_Bus_Slave_Diff_UART_Debug_CUSTOM_INTR_HANDLER)
        Han_Bus_Slave_Diff_UART_Debug_customIntrHandler = func; /* Register interrupt handler */
    #else
        if (NULL != func)
        {
            /* Suppress compiler warning */
        }
    #endif /* !defined (CY_REMOVE_Han_Bus_Slave_Diff_UART_Debug_CUSTOM_INTR_HANDLER) */
    }
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_IRQ_INTERNAL) */


/*******************************************************************************
* Function Name: Han_Bus_Slave_Diff_UART_Debug_ScbModeEnableIntr
****************************************************************************//**
*
*  Enables an interrupt for a specific mode.
*
*******************************************************************************/
static void Han_Bus_Slave_Diff_UART_Debug_ScbEnableIntr(void)
{
#if (Han_Bus_Slave_Diff_UART_Debug_SCB_IRQ_INTERNAL)
    /* Enable interrupt in NVIC */
    #if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG)
        if (0u != Han_Bus_Slave_Diff_UART_Debug_scbEnableIntr)
        {
            Han_Bus_Slave_Diff_UART_Debug_EnableInt();
        }

    #else
        Han_Bus_Slave_Diff_UART_Debug_EnableInt();

    #endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG) */
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_IRQ_INTERNAL) */
}


/*******************************************************************************
* Function Name: Han_Bus_Slave_Diff_UART_Debug_ScbModePostEnable
****************************************************************************//**
*
*  Calls the PostEnable function for a specific operation mode.
*
*******************************************************************************/
static void Han_Bus_Slave_Diff_UART_Debug_ScbModePostEnable(void)
{
#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG)
#if (!Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1)
    if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_SPI_RUNTM_CFG)
    {
        Han_Bus_Slave_Diff_UART_Debug_SpiPostEnable();
    }
    else if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UART_RUNTM_CFG)
    {
        Han_Bus_Slave_Diff_UART_Debug_UartPostEnable();
    }
    else
    {
        /* Unknown mode: do nothing */
    }
#endif /* (!Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1) */

#elif (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_SPI_CONST_CFG)
    Han_Bus_Slave_Diff_UART_Debug_SpiPostEnable();

#elif (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UART_CONST_CFG)
    Han_Bus_Slave_Diff_UART_Debug_UartPostEnable();

#else
    /* Unknown mode: do nothing */
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: Han_Bus_Slave_Diff_UART_Debug_ScbModeStop
****************************************************************************//**
*
*  Calls the Stop function for a specific operation mode.
*
*******************************************************************************/
static void Han_Bus_Slave_Diff_UART_Debug_ScbModeStop(void)
{
#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG)
    if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_I2C_RUNTM_CFG)
    {
        Han_Bus_Slave_Diff_UART_Debug_I2CStop();
    }
    else if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_EZI2C_RUNTM_CFG)
    {
        Han_Bus_Slave_Diff_UART_Debug_EzI2CStop();
    }
#if (!Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1)
    else if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_SPI_RUNTM_CFG)
    {
        Han_Bus_Slave_Diff_UART_Debug_SpiStop();
    }
    else if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UART_RUNTM_CFG)
    {
        Han_Bus_Slave_Diff_UART_Debug_UartStop();
    }
#endif /* (!Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1) */
    else
    {
        /* Unknown mode: do nothing */
    }
#elif (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_I2C_CONST_CFG)
    Han_Bus_Slave_Diff_UART_Debug_I2CStop();

#elif (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_EZI2C_CONST_CFG)
    Han_Bus_Slave_Diff_UART_Debug_EzI2CStop();

#elif (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_SPI_CONST_CFG)
    Han_Bus_Slave_Diff_UART_Debug_SpiStop();

#elif (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UART_CONST_CFG)
    Han_Bus_Slave_Diff_UART_Debug_UartStop();

#else
    /* Unknown mode: do nothing */
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG) */
}


#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG)
    /*******************************************************************************
    * Function Name: Han_Bus_Slave_Diff_UART_Debug_SetPins
    ****************************************************************************//**
    *
    *  Sets the pins settings accordingly to the selected operation mode.
    *  Only available in the Unconfigured operation mode. The mode specific
    *  initialization function calls it.
    *  Pins configuration is set by PSoC Creator when a specific mode of operation
    *  is selected in design time.
    *
    *  \param mode:      Mode of SCB operation.
    *  \param subMode:   Sub-mode of SCB operation. It is only required for SPI and UART
    *             modes.
    *  \param uartEnableMask: enables TX or RX direction and RTS and CTS signals.
    *
    *******************************************************************************/
    void Han_Bus_Slave_Diff_UART_Debug_SetPins(uint32 mode, uint32 subMode, uint32 uartEnableMask)
    {
        uint32 pinsDm[Han_Bus_Slave_Diff_UART_Debug_SCB_PINS_NUMBER];
        uint32 i;
        
    #if (!Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1)
        uint32 pinsInBuf = 0u;
    #endif /* (!Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1) */
        
        uint32 hsiomSel[Han_Bus_Slave_Diff_UART_Debug_SCB_PINS_NUMBER] = 
        {
            Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_HSIOM_SEL_GPIO,
            Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_HSIOM_SEL_GPIO,
            0u,
            0u,
            0u,
            0u,
            0u,
        };

    #if (Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1)
        /* Supress compiler warning. */
        if ((0u == subMode) || (0u == uartEnableMask))
        {
        }
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1) */

        /* Set default HSIOM to GPIO and Drive Mode to Analog Hi-Z */
        for (i = 0u; i < Han_Bus_Slave_Diff_UART_Debug_SCB_PINS_NUMBER; i++)
        {
            pinsDm[i] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_ALG_HIZ;
        }

        if ((Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_I2C   == mode) ||
            (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_EZI2C == mode))
        {
        #if (Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN)
            hsiomSel[Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_HSIOM_SEL_I2C;
            pinsDm  [Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_OD_LO;
        #elif (Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_PIN)
            hsiomSel[Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_HSIOM_SEL_I2C;
            pinsDm  [Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_OD_LO;
        #else
        #endif /* (Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN) */
        
        #if (Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN)
            hsiomSel[Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_HSIOM_SEL_I2C;
            pinsDm  [Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_OD_LO;
        #endif /* (Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN) */
        }
    #if (!Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1)
        else if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_SPI == mode)
        {
        #if (Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN)
            hsiomSel[Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_HSIOM_SEL_SPI;
        #elif (Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_PIN)
            hsiomSel[Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_HSIOM_SEL_SPI;
        #else
        #endif /* (Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN) */
        
        #if (Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN)
            hsiomSel[Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_HSIOM_SEL_SPI;
        #endif /* (Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN) */
        
        #if (Han_Bus_Slave_Diff_UART_Debug_SCLK_PIN)
            hsiomSel[Han_Bus_Slave_Diff_UART_Debug_SCLK_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_SCLK_HSIOM_SEL_SPI;
        #endif /* (Han_Bus_Slave_Diff_UART_Debug_SCLK_PIN) */

            if (Han_Bus_Slave_Diff_UART_Debug_SPI_SLAVE == subMode)
            {
                /* Slave */
                pinsDm[Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_DIG_HIZ;
                pinsDm[Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_STRONG;
                pinsDm[Han_Bus_Slave_Diff_UART_Debug_SCLK_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_DIG_HIZ;

            #if (Han_Bus_Slave_Diff_UART_Debug_SS0_PIN)
                /* Only SS0 is valid choice for Slave */
                hsiomSel[Han_Bus_Slave_Diff_UART_Debug_SS0_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_SS0_HSIOM_SEL_SPI;
                pinsDm  [Han_Bus_Slave_Diff_UART_Debug_SS0_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_DIG_HIZ;
            #endif /* (Han_Bus_Slave_Diff_UART_Debug_SS0_PIN) */

            #if (Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN)
                /* Disable input buffer */
                 pinsInBuf |= Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN_MASK;
            #endif /* (Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN) */
            }
            else 
            {
                /* (Master) */
                pinsDm[Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_STRONG;
                pinsDm[Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_DIG_HIZ;
                pinsDm[Han_Bus_Slave_Diff_UART_Debug_SCLK_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_STRONG;

            #if (Han_Bus_Slave_Diff_UART_Debug_SS0_PIN)
                hsiomSel [Han_Bus_Slave_Diff_UART_Debug_SS0_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_SS0_HSIOM_SEL_SPI;
                pinsDm   [Han_Bus_Slave_Diff_UART_Debug_SS0_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_STRONG;
                pinsInBuf |= Han_Bus_Slave_Diff_UART_Debug_SS0_PIN_MASK;
            #endif /* (Han_Bus_Slave_Diff_UART_Debug_SS0_PIN) */

            #if (Han_Bus_Slave_Diff_UART_Debug_SS1_PIN)
                hsiomSel [Han_Bus_Slave_Diff_UART_Debug_SS1_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_SS1_HSIOM_SEL_SPI;
                pinsDm   [Han_Bus_Slave_Diff_UART_Debug_SS1_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_STRONG;
                pinsInBuf |= Han_Bus_Slave_Diff_UART_Debug_SS1_PIN_MASK;
            #endif /* (Han_Bus_Slave_Diff_UART_Debug_SS1_PIN) */

            #if (Han_Bus_Slave_Diff_UART_Debug_SS2_PIN)
                hsiomSel [Han_Bus_Slave_Diff_UART_Debug_SS2_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_SS2_HSIOM_SEL_SPI;
                pinsDm   [Han_Bus_Slave_Diff_UART_Debug_SS2_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_STRONG;
                pinsInBuf |= Han_Bus_Slave_Diff_UART_Debug_SS2_PIN_MASK;
            #endif /* (Han_Bus_Slave_Diff_UART_Debug_SS2_PIN) */

            #if (Han_Bus_Slave_Diff_UART_Debug_SS3_PIN)
                hsiomSel [Han_Bus_Slave_Diff_UART_Debug_SS3_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_SS3_HSIOM_SEL_SPI;
                pinsDm   [Han_Bus_Slave_Diff_UART_Debug_SS3_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_STRONG;
                pinsInBuf |= Han_Bus_Slave_Diff_UART_Debug_SS3_PIN_MASK;
            #endif /* (Han_Bus_Slave_Diff_UART_Debug_SS3_PIN) */

                /* Disable input buffers */
            #if (Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN)
                pinsInBuf |= Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN_MASK;
            #elif (Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_PIN)
                pinsInBuf |= Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_PIN_MASK;
            #else
            #endif /* (Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN) */

            #if (Han_Bus_Slave_Diff_UART_Debug_SCLK_PIN)
                pinsInBuf |= Han_Bus_Slave_Diff_UART_Debug_SCLK_PIN_MASK;
            #endif /* (Han_Bus_Slave_Diff_UART_Debug_SCLK_PIN) */
            }
        }
        else /* UART */
        {
            if (Han_Bus_Slave_Diff_UART_Debug_UART_MODE_SMARTCARD == subMode)
            {
                /* SmartCard */
            #if (Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN)
                hsiomSel[Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_HSIOM_SEL_UART;
                pinsDm  [Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_OD_LO;
            #endif /* (Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN) */
            }
            else /* Standard or IrDA */
            {
                if (0u != (Han_Bus_Slave_Diff_UART_Debug_UART_RX_PIN_ENABLE & uartEnableMask))
                {
                #if (Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN)
                    hsiomSel[Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_HSIOM_SEL_UART;
                    pinsDm  [Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_DIG_HIZ;
                #elif (Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_PIN)
                    hsiomSel[Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_HSIOM_SEL_UART;
                    pinsDm  [Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_DIG_HIZ;
                #else
                #endif /* (Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN) */
                }

                if (0u != (Han_Bus_Slave_Diff_UART_Debug_UART_TX_PIN_ENABLE & uartEnableMask))
                {
                #if (Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN)
                    hsiomSel[Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_HSIOM_SEL_UART;
                    pinsDm  [Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_STRONG;
                    
                    /* Disable input buffer */
                    pinsInBuf |= Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN_MASK;
                #endif /* (Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN) */
                }

            #if !(Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V0 || Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1)
                if (Han_Bus_Slave_Diff_UART_Debug_UART_MODE_STD == subMode)
                {
                    if (0u != (Han_Bus_Slave_Diff_UART_Debug_UART_CTS_PIN_ENABLE & uartEnableMask))
                    {
                        /* CTS input is multiplexed with SCLK */
                    #if (Han_Bus_Slave_Diff_UART_Debug_SCLK_PIN)
                        hsiomSel[Han_Bus_Slave_Diff_UART_Debug_SCLK_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_SCLK_HSIOM_SEL_UART;
                        pinsDm  [Han_Bus_Slave_Diff_UART_Debug_SCLK_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_DIG_HIZ;
                    #endif /* (Han_Bus_Slave_Diff_UART_Debug_SCLK_PIN) */
                    }

                    if (0u != (Han_Bus_Slave_Diff_UART_Debug_UART_RTS_PIN_ENABLE & uartEnableMask))
                    {
                        /* RTS output is multiplexed with SS0 */
                    #if (Han_Bus_Slave_Diff_UART_Debug_SS0_PIN)
                        hsiomSel[Han_Bus_Slave_Diff_UART_Debug_SS0_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_SS0_HSIOM_SEL_UART;
                        pinsDm  [Han_Bus_Slave_Diff_UART_Debug_SS0_PIN_INDEX] = Han_Bus_Slave_Diff_UART_Debug_PIN_DM_STRONG;
                        
                        /* Disable input buffer */
                        pinsInBuf |= Han_Bus_Slave_Diff_UART_Debug_SS0_PIN_MASK;
                    #endif /* (Han_Bus_Slave_Diff_UART_Debug_SS0_PIN) */
                    }
                }
            #endif /* !(Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V0 || Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1) */
            }
        }
    #endif /* (!Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1) */

    /* Configure pins: set HSIOM, DM and InputBufEnable */
    /* Note: the DR register settings do not effect the pin output if HSIOM is other than GPIO */

    #if (Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN)
        Han_Bus_Slave_Diff_UART_Debug_SET_HSIOM_SEL(Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_HSIOM_REG,
                                       Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_HSIOM_MASK,
                                       Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_HSIOM_POS,
                                        hsiomSel[Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN_INDEX]);

        Han_Bus_Slave_Diff_UART_Debug_uart_rx_i2c_scl_spi_mosi_SetDriveMode((uint8) pinsDm[Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN_INDEX]);

        #if (!Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1)
            Han_Bus_Slave_Diff_UART_Debug_SET_INP_DIS(Han_Bus_Slave_Diff_UART_Debug_uart_rx_i2c_scl_spi_mosi_INP_DIS,
                                         Han_Bus_Slave_Diff_UART_Debug_uart_rx_i2c_scl_spi_mosi_MASK,
                                         (0u != (pinsInBuf & Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN_MASK)));
        #endif /* (!Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1) */
    
    #elif (Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_PIN)
        Han_Bus_Slave_Diff_UART_Debug_SET_HSIOM_SEL(Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_HSIOM_REG,
                                       Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_HSIOM_MASK,
                                       Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_HSIOM_POS,
                                       hsiomSel[Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_PIN_INDEX]);

        Han_Bus_Slave_Diff_UART_Debug_uart_rx_wake_i2c_scl_spi_mosi_SetDriveMode((uint8)
                                                               pinsDm[Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_PIN_INDEX]);

        Han_Bus_Slave_Diff_UART_Debug_SET_INP_DIS(Han_Bus_Slave_Diff_UART_Debug_uart_rx_wake_i2c_scl_spi_mosi_INP_DIS,
                                     Han_Bus_Slave_Diff_UART_Debug_uart_rx_wake_i2c_scl_spi_mosi_MASK,
                                     (0u != (pinsInBuf & Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_PIN_MASK)));

         /* Set interrupt on falling edge */
        Han_Bus_Slave_Diff_UART_Debug_SET_INCFG_TYPE(Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_INTCFG_REG,
                                        Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_INTCFG_TYPE_MASK,
                                        Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_INTCFG_TYPE_POS,
                                        Han_Bus_Slave_Diff_UART_Debug_INTCFG_TYPE_FALLING_EDGE);
    #else
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_SCL_MOSI_PIN) */

    #if (Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN)
        Han_Bus_Slave_Diff_UART_Debug_SET_HSIOM_SEL(Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_HSIOM_REG,
                                       Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_HSIOM_MASK,
                                       Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_HSIOM_POS,
                                        hsiomSel[Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN_INDEX]);

        Han_Bus_Slave_Diff_UART_Debug_uart_tx_i2c_sda_spi_miso_SetDriveMode((uint8) pinsDm[Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN_INDEX]);

    #if (!Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1)
        Han_Bus_Slave_Diff_UART_Debug_SET_INP_DIS(Han_Bus_Slave_Diff_UART_Debug_uart_tx_i2c_sda_spi_miso_INP_DIS,
                                     Han_Bus_Slave_Diff_UART_Debug_uart_tx_i2c_sda_spi_miso_MASK,
                                    (0u != (pinsInBuf & Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN_MASK)));
    #endif /* (!Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1) */
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_RX_SCL_MOSI_PIN) */

    #if (Han_Bus_Slave_Diff_UART_Debug_SCLK_PIN)
        Han_Bus_Slave_Diff_UART_Debug_SET_HSIOM_SEL(Han_Bus_Slave_Diff_UART_Debug_SCLK_HSIOM_REG,
                                       Han_Bus_Slave_Diff_UART_Debug_SCLK_HSIOM_MASK,
                                       Han_Bus_Slave_Diff_UART_Debug_SCLK_HSIOM_POS,
                                       hsiomSel[Han_Bus_Slave_Diff_UART_Debug_SCLK_PIN_INDEX]);

        Han_Bus_Slave_Diff_UART_Debug_spi_sclk_SetDriveMode((uint8) pinsDm[Han_Bus_Slave_Diff_UART_Debug_SCLK_PIN_INDEX]);

        Han_Bus_Slave_Diff_UART_Debug_SET_INP_DIS(Han_Bus_Slave_Diff_UART_Debug_spi_sclk_INP_DIS,
                                     Han_Bus_Slave_Diff_UART_Debug_spi_sclk_MASK,
                                     (0u != (pinsInBuf & Han_Bus_Slave_Diff_UART_Debug_SCLK_PIN_MASK)));
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_SCLK_PIN) */

    #if (Han_Bus_Slave_Diff_UART_Debug_SS0_PIN)
        Han_Bus_Slave_Diff_UART_Debug_SET_HSIOM_SEL(Han_Bus_Slave_Diff_UART_Debug_SS0_HSIOM_REG,
                                       Han_Bus_Slave_Diff_UART_Debug_SS0_HSIOM_MASK,
                                       Han_Bus_Slave_Diff_UART_Debug_SS0_HSIOM_POS,
                                       hsiomSel[Han_Bus_Slave_Diff_UART_Debug_SS0_PIN_INDEX]);

        Han_Bus_Slave_Diff_UART_Debug_spi_ss0_SetDriveMode((uint8) pinsDm[Han_Bus_Slave_Diff_UART_Debug_SS0_PIN_INDEX]);

        Han_Bus_Slave_Diff_UART_Debug_SET_INP_DIS(Han_Bus_Slave_Diff_UART_Debug_spi_ss0_INP_DIS,
                                     Han_Bus_Slave_Diff_UART_Debug_spi_ss0_MASK,
                                     (0u != (pinsInBuf & Han_Bus_Slave_Diff_UART_Debug_SS0_PIN_MASK)));
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_SS0_PIN) */

    #if (Han_Bus_Slave_Diff_UART_Debug_SS1_PIN)
        Han_Bus_Slave_Diff_UART_Debug_SET_HSIOM_SEL(Han_Bus_Slave_Diff_UART_Debug_SS1_HSIOM_REG,
                                       Han_Bus_Slave_Diff_UART_Debug_SS1_HSIOM_MASK,
                                       Han_Bus_Slave_Diff_UART_Debug_SS1_HSIOM_POS,
                                       hsiomSel[Han_Bus_Slave_Diff_UART_Debug_SS1_PIN_INDEX]);

        Han_Bus_Slave_Diff_UART_Debug_spi_ss1_SetDriveMode((uint8) pinsDm[Han_Bus_Slave_Diff_UART_Debug_SS1_PIN_INDEX]);

        Han_Bus_Slave_Diff_UART_Debug_SET_INP_DIS(Han_Bus_Slave_Diff_UART_Debug_spi_ss1_INP_DIS,
                                     Han_Bus_Slave_Diff_UART_Debug_spi_ss1_MASK,
                                     (0u != (pinsInBuf & Han_Bus_Slave_Diff_UART_Debug_SS1_PIN_MASK)));
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_SS1_PIN) */

    #if (Han_Bus_Slave_Diff_UART_Debug_SS2_PIN)
        Han_Bus_Slave_Diff_UART_Debug_SET_HSIOM_SEL(Han_Bus_Slave_Diff_UART_Debug_SS2_HSIOM_REG,
                                       Han_Bus_Slave_Diff_UART_Debug_SS2_HSIOM_MASK,
                                       Han_Bus_Slave_Diff_UART_Debug_SS2_HSIOM_POS,
                                       hsiomSel[Han_Bus_Slave_Diff_UART_Debug_SS2_PIN_INDEX]);

        Han_Bus_Slave_Diff_UART_Debug_spi_ss2_SetDriveMode((uint8) pinsDm[Han_Bus_Slave_Diff_UART_Debug_SS2_PIN_INDEX]);

        Han_Bus_Slave_Diff_UART_Debug_SET_INP_DIS(Han_Bus_Slave_Diff_UART_Debug_spi_ss2_INP_DIS,
                                     Han_Bus_Slave_Diff_UART_Debug_spi_ss2_MASK,
                                     (0u != (pinsInBuf & Han_Bus_Slave_Diff_UART_Debug_SS2_PIN_MASK)));
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_SS2_PIN) */

    #if (Han_Bus_Slave_Diff_UART_Debug_SS3_PIN)
        Han_Bus_Slave_Diff_UART_Debug_SET_HSIOM_SEL(Han_Bus_Slave_Diff_UART_Debug_SS3_HSIOM_REG,
                                       Han_Bus_Slave_Diff_UART_Debug_SS3_HSIOM_MASK,
                                       Han_Bus_Slave_Diff_UART_Debug_SS3_HSIOM_POS,
                                       hsiomSel[Han_Bus_Slave_Diff_UART_Debug_SS3_PIN_INDEX]);

        Han_Bus_Slave_Diff_UART_Debug_spi_ss3_SetDriveMode((uint8) pinsDm[Han_Bus_Slave_Diff_UART_Debug_SS3_PIN_INDEX]);

        Han_Bus_Slave_Diff_UART_Debug_SET_INP_DIS(Han_Bus_Slave_Diff_UART_Debug_spi_ss3_INP_DIS,
                                     Han_Bus_Slave_Diff_UART_Debug_spi_ss3_MASK,
                                     (0u != (pinsInBuf & Han_Bus_Slave_Diff_UART_Debug_SS3_PIN_MASK)));
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_SS3_PIN) */
    }

#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG) */


#if (Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V0 || Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1)
    /*******************************************************************************
    * Function Name: Han_Bus_Slave_Diff_UART_Debug_I2CSlaveNackGeneration
    ****************************************************************************//**
    *
    *  Sets command to generate NACK to the address or data.
    *
    *******************************************************************************/
    void Han_Bus_Slave_Diff_UART_Debug_I2CSlaveNackGeneration(void)
    {
        /* Check for EC_AM toggle condition: EC_AM and clock stretching for address are enabled */
        if ((0u != (Han_Bus_Slave_Diff_UART_Debug_CTRL_REG & Han_Bus_Slave_Diff_UART_Debug_CTRL_EC_AM_MODE)) &&
            (0u == (Han_Bus_Slave_Diff_UART_Debug_I2C_CTRL_REG & Han_Bus_Slave_Diff_UART_Debug_I2C_CTRL_S_NOT_READY_ADDR_NACK)))
        {
            /* Toggle EC_AM before NACK generation */
            Han_Bus_Slave_Diff_UART_Debug_CTRL_REG &= ~Han_Bus_Slave_Diff_UART_Debug_CTRL_EC_AM_MODE;
            Han_Bus_Slave_Diff_UART_Debug_CTRL_REG |=  Han_Bus_Slave_Diff_UART_Debug_CTRL_EC_AM_MODE;
        }

        Han_Bus_Slave_Diff_UART_Debug_I2C_SLAVE_CMD_REG = Han_Bus_Slave_Diff_UART_Debug_I2C_SLAVE_CMD_S_NACK;
    }
#endif /* (Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V0 || Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1) */


/* [] END OF FILE */
