/***************************************************************************//**
* \file Han_Bus_Slave_Diff_UART_Debug_BOOT.h
* \version 3.20
*
* \brief
*  This file provides constants and parameter values of the bootloader
*  communication APIs for the SCB Component.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2014-2016, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_BOOT_Han_Bus_Slave_Diff_UART_Debug_H)
#define CY_SCB_BOOT_Han_Bus_Slave_Diff_UART_Debug_H

#include "Han_Bus_Slave_Diff_UART_Debug_PVT.h"

#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_I2C_INC)
    #include "Han_Bus_Slave_Diff_UART_Debug_I2C.h"
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_I2C_INC) */

#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_EZI2C_INC)
    #include "Han_Bus_Slave_Diff_UART_Debug_EZI2C.h"
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_EZI2C_INC) */

#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_SPI_INC || Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UART_INC)
    #include "Han_Bus_Slave_Diff_UART_Debug_SPI_UART.h"
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_SPI_INC || Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UART_INC) */


/***************************************
*  Conditional Compilation Parameters
****************************************/

/* Bootloader communication interface enable */
#define Han_Bus_Slave_Diff_UART_Debug_BTLDR_COMM_ENABLED ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Han_Bus_Slave_Diff_UART_Debug) || \
                                             (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))

/* Enable I2C bootloader communication */
#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_I2C_INC)
    #define Han_Bus_Slave_Diff_UART_Debug_I2C_BTLDR_COMM_ENABLED     (Han_Bus_Slave_Diff_UART_Debug_BTLDR_COMM_ENABLED && \
                                                            (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             Han_Bus_Slave_Diff_UART_Debug_I2C_SLAVE_CONST))
#else
     #define Han_Bus_Slave_Diff_UART_Debug_I2C_BTLDR_COMM_ENABLED    (0u)
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_I2C_INC) */

/* EZI2C does not support bootloader communication. Provide empty APIs */
#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_EZI2C_INC)
    #define Han_Bus_Slave_Diff_UART_Debug_EZI2C_BTLDR_COMM_ENABLED   (Han_Bus_Slave_Diff_UART_Debug_BTLDR_COMM_ENABLED && \
                                                         Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG)
#else
    #define Han_Bus_Slave_Diff_UART_Debug_EZI2C_BTLDR_COMM_ENABLED   (0u)
#endif /* (Han_Bus_Slave_Diff_UART_Debug_EZI2C_BTLDR_COMM_ENABLED) */

/* Enable SPI bootloader communication */
#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_SPI_INC)
    #define Han_Bus_Slave_Diff_UART_Debug_SPI_BTLDR_COMM_ENABLED     (Han_Bus_Slave_Diff_UART_Debug_BTLDR_COMM_ENABLED && \
                                                            (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             Han_Bus_Slave_Diff_UART_Debug_SPI_SLAVE_CONST))
#else
        #define Han_Bus_Slave_Diff_UART_Debug_SPI_BTLDR_COMM_ENABLED (0u)
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SPI_BTLDR_COMM_ENABLED) */

/* Enable UART bootloader communication */
#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UART_INC)
       #define Han_Bus_Slave_Diff_UART_Debug_UART_BTLDR_COMM_ENABLED    (Han_Bus_Slave_Diff_UART_Debug_BTLDR_COMM_ENABLED && \
                                                            (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             (Han_Bus_Slave_Diff_UART_Debug_UART_RX_DIRECTION && \
                                                              Han_Bus_Slave_Diff_UART_Debug_UART_TX_DIRECTION)))
#else
     #define Han_Bus_Slave_Diff_UART_Debug_UART_BTLDR_COMM_ENABLED   (0u)
#endif /* (Han_Bus_Slave_Diff_UART_Debug_UART_BTLDR_COMM_ENABLED) */

/* Enable bootloader communication */
#define Han_Bus_Slave_Diff_UART_Debug_BTLDR_COMM_MODE_ENABLED    (Han_Bus_Slave_Diff_UART_Debug_I2C_BTLDR_COMM_ENABLED   || \
                                                     Han_Bus_Slave_Diff_UART_Debug_SPI_BTLDR_COMM_ENABLED   || \
                                                     Han_Bus_Slave_Diff_UART_Debug_EZI2C_BTLDR_COMM_ENABLED || \
                                                     Han_Bus_Slave_Diff_UART_Debug_UART_BTLDR_COMM_ENABLED)


/***************************************
*        Function Prototypes
***************************************/

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Han_Bus_Slave_Diff_UART_Debug_I2C_BTLDR_COMM_ENABLED)
    /* I2C Bootloader physical layer functions */
    void Han_Bus_Slave_Diff_UART_Debug_I2CCyBtldrCommStart(void);
    void Han_Bus_Slave_Diff_UART_Debug_I2CCyBtldrCommStop (void);
    void Han_Bus_Slave_Diff_UART_Debug_I2CCyBtldrCommReset(void);
    cystatus Han_Bus_Slave_Diff_UART_Debug_I2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus Han_Bus_Slave_Diff_UART_Debug_I2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map I2C specific bootloader communication APIs to SCB specific APIs */
    #if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_I2C_CONST_CFG)
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommStart   Han_Bus_Slave_Diff_UART_Debug_I2CCyBtldrCommStart
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommStop    Han_Bus_Slave_Diff_UART_Debug_I2CCyBtldrCommStop
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommReset   Han_Bus_Slave_Diff_UART_Debug_I2CCyBtldrCommReset
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommRead    Han_Bus_Slave_Diff_UART_Debug_I2CCyBtldrCommRead
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommWrite   Han_Bus_Slave_Diff_UART_Debug_I2CCyBtldrCommWrite
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_I2C_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Han_Bus_Slave_Diff_UART_Debug_I2C_BTLDR_COMM_ENABLED) */


#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Han_Bus_Slave_Diff_UART_Debug_EZI2C_BTLDR_COMM_ENABLED)
    /* Bootloader physical layer functions */
    void Han_Bus_Slave_Diff_UART_Debug_EzI2CCyBtldrCommStart(void);
    void Han_Bus_Slave_Diff_UART_Debug_EzI2CCyBtldrCommStop (void);
    void Han_Bus_Slave_Diff_UART_Debug_EzI2CCyBtldrCommReset(void);
    cystatus Han_Bus_Slave_Diff_UART_Debug_EzI2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus Han_Bus_Slave_Diff_UART_Debug_EzI2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map EZI2C specific bootloader communication APIs to SCB specific APIs */
    #if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_EZI2C_CONST_CFG)
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommStart   Han_Bus_Slave_Diff_UART_Debug_EzI2CCyBtldrCommStart
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommStop    Han_Bus_Slave_Diff_UART_Debug_EzI2CCyBtldrCommStop
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommReset   Han_Bus_Slave_Diff_UART_Debug_EzI2CCyBtldrCommReset
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommRead    Han_Bus_Slave_Diff_UART_Debug_EzI2CCyBtldrCommRead
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommWrite   Han_Bus_Slave_Diff_UART_Debug_EzI2CCyBtldrCommWrite
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_EZI2C_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Han_Bus_Slave_Diff_UART_Debug_EZI2C_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Han_Bus_Slave_Diff_UART_Debug_SPI_BTLDR_COMM_ENABLED)
    /* SPI Bootloader physical layer functions */
    void Han_Bus_Slave_Diff_UART_Debug_SpiCyBtldrCommStart(void);
    void Han_Bus_Slave_Diff_UART_Debug_SpiCyBtldrCommStop (void);
    void Han_Bus_Slave_Diff_UART_Debug_SpiCyBtldrCommReset(void);
    cystatus Han_Bus_Slave_Diff_UART_Debug_SpiCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus Han_Bus_Slave_Diff_UART_Debug_SpiCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map SPI specific bootloader communication APIs to SCB specific APIs */
    #if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_SPI_CONST_CFG)
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommStart   Han_Bus_Slave_Diff_UART_Debug_SpiCyBtldrCommStart
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommStop    Han_Bus_Slave_Diff_UART_Debug_SpiCyBtldrCommStop
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommReset   Han_Bus_Slave_Diff_UART_Debug_SpiCyBtldrCommReset
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommRead    Han_Bus_Slave_Diff_UART_Debug_SpiCyBtldrCommRead
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommWrite   Han_Bus_Slave_Diff_UART_Debug_SpiCyBtldrCommWrite
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_SPI_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Han_Bus_Slave_Diff_UART_Debug_SPI_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Han_Bus_Slave_Diff_UART_Debug_UART_BTLDR_COMM_ENABLED)
    /* UART Bootloader physical layer functions */
    void Han_Bus_Slave_Diff_UART_Debug_UartCyBtldrCommStart(void);
    void Han_Bus_Slave_Diff_UART_Debug_UartCyBtldrCommStop (void);
    void Han_Bus_Slave_Diff_UART_Debug_UartCyBtldrCommReset(void);
    cystatus Han_Bus_Slave_Diff_UART_Debug_UartCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus Han_Bus_Slave_Diff_UART_Debug_UartCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map UART specific bootloader communication APIs to SCB specific APIs */
    #if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UART_CONST_CFG)
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommStart   Han_Bus_Slave_Diff_UART_Debug_UartCyBtldrCommStart
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommStop    Han_Bus_Slave_Diff_UART_Debug_UartCyBtldrCommStop
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommReset   Han_Bus_Slave_Diff_UART_Debug_UartCyBtldrCommReset
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommRead    Han_Bus_Slave_Diff_UART_Debug_UartCyBtldrCommRead
        #define Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommWrite   Han_Bus_Slave_Diff_UART_Debug_UartCyBtldrCommWrite
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UART_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Han_Bus_Slave_Diff_UART_Debug_UART_BTLDR_COMM_ENABLED) */

/**
* \addtogroup group_bootloader
* @{
*/

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Han_Bus_Slave_Diff_UART_Debug_BTLDR_COMM_ENABLED)
    #if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG)
        /* Bootloader physical layer functions */
        void Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommStart(void);
        void Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommStop (void);
        void Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommReset(void);
        cystatus Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
        cystatus Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG) */

    /* Map SCB specific bootloader communication APIs to common APIs */
    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Han_Bus_Slave_Diff_UART_Debug)
        #define CyBtldrCommStart    Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommStart
        #define CyBtldrCommStop     Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommStop
        #define CyBtldrCommReset    Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommReset
        #define CyBtldrCommWrite    Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommWrite
        #define CyBtldrCommRead     Han_Bus_Slave_Diff_UART_Debug_CyBtldrCommRead
    #endif /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Han_Bus_Slave_Diff_UART_Debug) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Han_Bus_Slave_Diff_UART_Debug_BTLDR_COMM_ENABLED) */

/** @} group_bootloader */

/***************************************
*           API Constants
***************************************/

/* Timeout unit in milliseconds */
#define Han_Bus_Slave_Diff_UART_Debug_WAIT_1_MS  (1u)

/* Return number of bytes to copy into bootloader buffer */
#define Han_Bus_Slave_Diff_UART_Debug_BYTES_TO_COPY(actBufSize, bufSize) \
                            ( ((uint32)(actBufSize) < (uint32)(bufSize)) ? \
                                ((uint32) (actBufSize)) : ((uint32) (bufSize)) )

/* Size of Read/Write buffers for I2C bootloader  */
#define Han_Bus_Slave_Diff_UART_Debug_I2C_BTLDR_SIZEOF_READ_BUFFER   (64u)
#define Han_Bus_Slave_Diff_UART_Debug_I2C_BTLDR_SIZEOF_WRITE_BUFFER  (64u)

/* Byte to byte time interval: calculated basing on current component
* data rate configuration, can be defined in project if required.
*/
#ifndef Han_Bus_Slave_Diff_UART_Debug_SPI_BYTE_TO_BYTE
    #define Han_Bus_Slave_Diff_UART_Debug_SPI_BYTE_TO_BYTE   (160u)
#endif

/* Byte to byte time interval: calculated basing on current component
* baud rate configuration, can be defined in the project if required.
*/
#ifndef Han_Bus_Slave_Diff_UART_Debug_UART_BYTE_TO_BYTE
    #define Han_Bus_Slave_Diff_UART_Debug_UART_BYTE_TO_BYTE  (23u)
#endif /* Han_Bus_Slave_Diff_UART_Debug_UART_BYTE_TO_BYTE */

#endif /* (CY_SCB_BOOT_Han_Bus_Slave_Diff_UART_Debug_H) */


/* [] END OF FILE */
