/***************************************************************************//**
* \file Han_Bus_Slave_Diff_UART_Debug_SPI_UART_INT.c
* \version 3.20
*
* \brief
*  This file provides the source code to the Interrupt Service Routine for
*  the SCB Component in SPI and UART modes.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2013-2016, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "Han_Bus_Slave_Diff_UART_Debug_PVT.h"
#include "Han_Bus_Slave_Diff_UART_Debug_SPI_UART_PVT.h"
#include "cyapicallbacks.h"

#if (Han_Bus_Slave_Diff_UART_Debug_SCB_IRQ_INTERNAL)
/*******************************************************************************
* Function Name: Han_Bus_Slave_Diff_UART_Debug_SPI_UART_ISR
****************************************************************************//**
*
*  Handles the Interrupt Service Routine for the SCB SPI or UART modes.
*
*******************************************************************************/
CY_ISR(Han_Bus_Slave_Diff_UART_Debug_SPI_UART_ISR)
{
#if (Han_Bus_Slave_Diff_UART_Debug_INTERNAL_RX_SW_BUFFER_CONST)
    uint32 locHead;
#endif /* (Han_Bus_Slave_Diff_UART_Debug_INTERNAL_RX_SW_BUFFER_CONST) */

#if (Han_Bus_Slave_Diff_UART_Debug_INTERNAL_TX_SW_BUFFER_CONST)
    uint32 locTail;
#endif /* (Han_Bus_Slave_Diff_UART_Debug_INTERNAL_TX_SW_BUFFER_CONST) */

#ifdef Han_Bus_Slave_Diff_UART_Debug_SPI_UART_ISR_ENTRY_CALLBACK
    Han_Bus_Slave_Diff_UART_Debug_SPI_UART_ISR_EntryCallback();
#endif /* Han_Bus_Slave_Diff_UART_Debug_SPI_UART_ISR_ENTRY_CALLBACK */

    if (NULL != Han_Bus_Slave_Diff_UART_Debug_customIntrHandler)
    {
        Han_Bus_Slave_Diff_UART_Debug_customIntrHandler();
    }

    #if(Han_Bus_Slave_Diff_UART_Debug_CHECK_SPI_WAKE_ENABLE)
    {
        /* Clear SPI wakeup source */
        Han_Bus_Slave_Diff_UART_Debug_ClearSpiExtClkInterruptSource(Han_Bus_Slave_Diff_UART_Debug_INTR_SPI_EC_WAKE_UP);
    }
    #endif

    #if (Han_Bus_Slave_Diff_UART_Debug_CHECK_RX_SW_BUFFER)
    {
        if (Han_Bus_Slave_Diff_UART_Debug_CHECK_INTR_RX_MASKED(Han_Bus_Slave_Diff_UART_Debug_INTR_RX_NOT_EMPTY))
        {
            do
            {
                /* Move local head index */
                locHead = (Han_Bus_Slave_Diff_UART_Debug_rxBufferHead + 1u);

                /* Adjust local head index */
                if (Han_Bus_Slave_Diff_UART_Debug_INTERNAL_RX_BUFFER_SIZE == locHead)
                {
                    locHead = 0u;
                }

                if (locHead == Han_Bus_Slave_Diff_UART_Debug_rxBufferTail)
                {
                    #if (Han_Bus_Slave_Diff_UART_Debug_CHECK_UART_RTS_CONTROL_FLOW)
                    {
                        /* There is no space in the software buffer - disable the
                        * RX Not Empty interrupt source. The data elements are
                        * still being received into the RX FIFO until the RTS signal
                        * stops the transmitter. After the data element is read from the
                        * buffer, the RX Not Empty interrupt source is enabled to
                        * move the next data element in the software buffer.
                        */
                        Han_Bus_Slave_Diff_UART_Debug_INTR_RX_MASK_REG &= ~Han_Bus_Slave_Diff_UART_Debug_INTR_RX_NOT_EMPTY;
                        break;
                    }
                    #else
                    {
                        /* Overflow: through away received data element */
                        (void) Han_Bus_Slave_Diff_UART_Debug_RX_FIFO_RD_REG;
                        Han_Bus_Slave_Diff_UART_Debug_rxBufferOverflow = (uint8) Han_Bus_Slave_Diff_UART_Debug_INTR_RX_OVERFLOW;
                    }
                    #endif
                }
                else
                {
                    /* Store received data */
                    Han_Bus_Slave_Diff_UART_Debug_PutWordInRxBuffer(locHead, Han_Bus_Slave_Diff_UART_Debug_RX_FIFO_RD_REG);

                    /* Move head index */
                    Han_Bus_Slave_Diff_UART_Debug_rxBufferHead = locHead;
                }
            }
            while(0u != Han_Bus_Slave_Diff_UART_Debug_GET_RX_FIFO_ENTRIES);

            Han_Bus_Slave_Diff_UART_Debug_ClearRxInterruptSource(Han_Bus_Slave_Diff_UART_Debug_INTR_RX_NOT_EMPTY);
        }
    }
    #endif


    #if (Han_Bus_Slave_Diff_UART_Debug_CHECK_TX_SW_BUFFER)
    {
        if (Han_Bus_Slave_Diff_UART_Debug_CHECK_INTR_TX_MASKED(Han_Bus_Slave_Diff_UART_Debug_INTR_TX_NOT_FULL))
        {
            do
            {
                /* Check for room in TX software buffer */
                if (Han_Bus_Slave_Diff_UART_Debug_txBufferHead != Han_Bus_Slave_Diff_UART_Debug_txBufferTail)
                {
                    /* Move local tail index */
                    locTail = (Han_Bus_Slave_Diff_UART_Debug_txBufferTail + 1u);

                    /* Adjust local tail index */
                    if (Han_Bus_Slave_Diff_UART_Debug_TX_BUFFER_SIZE == locTail)
                    {
                        locTail = 0u;
                    }

                    /* Put data into TX FIFO */
                    Han_Bus_Slave_Diff_UART_Debug_TX_FIFO_WR_REG = Han_Bus_Slave_Diff_UART_Debug_GetWordFromTxBuffer(locTail);

                    /* Move tail index */
                    Han_Bus_Slave_Diff_UART_Debug_txBufferTail = locTail;
                }
                else
                {
                    /* TX software buffer is empty: complete transfer */
                    Han_Bus_Slave_Diff_UART_Debug_DISABLE_INTR_TX(Han_Bus_Slave_Diff_UART_Debug_INTR_TX_NOT_FULL);
                    break;
                }
            }
            while (Han_Bus_Slave_Diff_UART_Debug_SPI_UART_FIFO_SIZE != Han_Bus_Slave_Diff_UART_Debug_GET_TX_FIFO_ENTRIES);

            Han_Bus_Slave_Diff_UART_Debug_ClearTxInterruptSource(Han_Bus_Slave_Diff_UART_Debug_INTR_TX_NOT_FULL);
        }
    }
    #endif

#ifdef Han_Bus_Slave_Diff_UART_Debug_SPI_UART_ISR_EXIT_CALLBACK
    Han_Bus_Slave_Diff_UART_Debug_SPI_UART_ISR_ExitCallback();
#endif /* Han_Bus_Slave_Diff_UART_Debug_SPI_UART_ISR_EXIT_CALLBACK */

}

#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_IRQ_INTERNAL) */


/* [] END OF FILE */
