/***************************************************************************//**
* \file Han_Bus_Slave_Diff_UART_Debug_SPI_UART_PVT.h
* \version 3.20
*
* \brief
*  This private file provides constants and parameter values for the
*  SCB Component in SPI and UART modes.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2013-2016, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_SPI_UART_PVT_Han_Bus_Slave_Diff_UART_Debug_H)
#define CY_SCB_SPI_UART_PVT_Han_Bus_Slave_Diff_UART_Debug_H

#include "Han_Bus_Slave_Diff_UART_Debug_SPI_UART.h"


/***************************************
*     Internal Global Vars
***************************************/

#if (Han_Bus_Slave_Diff_UART_Debug_INTERNAL_RX_SW_BUFFER_CONST)
    extern volatile uint32  Han_Bus_Slave_Diff_UART_Debug_rxBufferHead;
    extern volatile uint32  Han_Bus_Slave_Diff_UART_Debug_rxBufferTail;
    
    /**
    * \addtogroup group_globals
    * @{
    */
    
    /** Sets when internal software receive buffer overflow
     *  was occurred.
    */  
    extern volatile uint8   Han_Bus_Slave_Diff_UART_Debug_rxBufferOverflow;
    /** @} globals */
#endif /* (Han_Bus_Slave_Diff_UART_Debug_INTERNAL_RX_SW_BUFFER_CONST) */

#if (Han_Bus_Slave_Diff_UART_Debug_INTERNAL_TX_SW_BUFFER_CONST)
    extern volatile uint32  Han_Bus_Slave_Diff_UART_Debug_txBufferHead;
    extern volatile uint32  Han_Bus_Slave_Diff_UART_Debug_txBufferTail;
#endif /* (Han_Bus_Slave_Diff_UART_Debug_INTERNAL_TX_SW_BUFFER_CONST) */

#if (Han_Bus_Slave_Diff_UART_Debug_INTERNAL_RX_SW_BUFFER)
    extern volatile uint8 Han_Bus_Slave_Diff_UART_Debug_rxBufferInternal[Han_Bus_Slave_Diff_UART_Debug_INTERNAL_RX_BUFFER_SIZE];
#endif /* (Han_Bus_Slave_Diff_UART_Debug_INTERNAL_RX_SW_BUFFER) */

#if (Han_Bus_Slave_Diff_UART_Debug_INTERNAL_TX_SW_BUFFER)
    extern volatile uint8 Han_Bus_Slave_Diff_UART_Debug_txBufferInternal[Han_Bus_Slave_Diff_UART_Debug_TX_BUFFER_SIZE];
#endif /* (Han_Bus_Slave_Diff_UART_Debug_INTERNAL_TX_SW_BUFFER) */


/***************************************
*     Private Function Prototypes
***************************************/

void Han_Bus_Slave_Diff_UART_Debug_SpiPostEnable(void);
void Han_Bus_Slave_Diff_UART_Debug_SpiStop(void);

#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_SPI_CONST_CFG)
    void Han_Bus_Slave_Diff_UART_Debug_SpiInit(void);
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_SPI_CONST_CFG) */

#if (Han_Bus_Slave_Diff_UART_Debug_SPI_WAKE_ENABLE_CONST)
    void Han_Bus_Slave_Diff_UART_Debug_SpiSaveConfig(void);
    void Han_Bus_Slave_Diff_UART_Debug_SpiRestoreConfig(void);
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SPI_WAKE_ENABLE_CONST) */

void Han_Bus_Slave_Diff_UART_Debug_UartPostEnable(void);
void Han_Bus_Slave_Diff_UART_Debug_UartStop(void);

#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UART_CONST_CFG)
    void Han_Bus_Slave_Diff_UART_Debug_UartInit(void);
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UART_CONST_CFG) */

#if (Han_Bus_Slave_Diff_UART_Debug_UART_WAKE_ENABLE_CONST)
    void Han_Bus_Slave_Diff_UART_Debug_UartSaveConfig(void);
    void Han_Bus_Slave_Diff_UART_Debug_UartRestoreConfig(void);
#endif /* (Han_Bus_Slave_Diff_UART_Debug_UART_WAKE_ENABLE_CONST) */


/***************************************
*         UART API Constants
***************************************/

/* UART RX and TX position to be used in Han_Bus_Slave_Diff_UART_Debug_SetPins() */
#define Han_Bus_Slave_Diff_UART_Debug_UART_RX_PIN_ENABLE    (Han_Bus_Slave_Diff_UART_Debug_UART_RX)
#define Han_Bus_Slave_Diff_UART_Debug_UART_TX_PIN_ENABLE    (Han_Bus_Slave_Diff_UART_Debug_UART_TX)

/* UART RTS and CTS position to be used in  Han_Bus_Slave_Diff_UART_Debug_SetPins() */
#define Han_Bus_Slave_Diff_UART_Debug_UART_RTS_PIN_ENABLE    (0x10u)
#define Han_Bus_Slave_Diff_UART_Debug_UART_CTS_PIN_ENABLE    (0x20u)


/***************************************
* The following code is DEPRECATED and
* must not be used.
***************************************/

/* Interrupt processing */
#define Han_Bus_Slave_Diff_UART_Debug_SpiUartEnableIntRx(intSourceMask)  Han_Bus_Slave_Diff_UART_Debug_SetRxInterruptMode(intSourceMask)
#define Han_Bus_Slave_Diff_UART_Debug_SpiUartEnableIntTx(intSourceMask)  Han_Bus_Slave_Diff_UART_Debug_SetTxInterruptMode(intSourceMask)
uint32  Han_Bus_Slave_Diff_UART_Debug_SpiUartDisableIntRx(void);
uint32  Han_Bus_Slave_Diff_UART_Debug_SpiUartDisableIntTx(void);


#endif /* (CY_SCB_SPI_UART_PVT_Han_Bus_Slave_Diff_UART_Debug_H) */


/* [] END OF FILE */
