/***************************************************************************//**
* \file Han_Bus_Slave_Diff_UART_Debug_UART.c
* \version 3.20
*
* \brief
*  This file provides the source code to the API for the SCB Component in
*  UART mode.
*
* Note:
*
*******************************************************************************
* \copyright
* Copyright 2013-2016, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "Han_Bus_Slave_Diff_UART_Debug_PVT.h"
#include "Han_Bus_Slave_Diff_UART_Debug_SPI_UART_PVT.h"
#include "cyapicallbacks.h"

#if (Han_Bus_Slave_Diff_UART_Debug_UART_WAKE_ENABLE_CONST && Han_Bus_Slave_Diff_UART_Debug_UART_RX_WAKEUP_IRQ)
    /**
    * \addtogroup group_globals
    * \{
    */
    /** This global variable determines whether to enable Skip Start
    * functionality when Han_Bus_Slave_Diff_UART_Debug_Sleep() function is called:
    * 0  disable, other values  enable. Default value is 1.
    * It is only available when Enable wakeup from Deep Sleep Mode is enabled.
    */
    uint8 Han_Bus_Slave_Diff_UART_Debug_skipStart = 1u;
    /** \} globals */
#endif /* (Han_Bus_Slave_Diff_UART_Debug_UART_WAKE_ENABLE_CONST && Han_Bus_Slave_Diff_UART_Debug_UART_RX_WAKEUP_IRQ) */

#if(Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG)

    /***************************************
    *  Configuration Structure Initialization
    ***************************************/

    const Han_Bus_Slave_Diff_UART_Debug_UART_INIT_STRUCT Han_Bus_Slave_Diff_UART_Debug_configUart =
    {
        Han_Bus_Slave_Diff_UART_Debug_UART_SUB_MODE,
        Han_Bus_Slave_Diff_UART_Debug_UART_DIRECTION,
        Han_Bus_Slave_Diff_UART_Debug_UART_DATA_BITS_NUM,
        Han_Bus_Slave_Diff_UART_Debug_UART_PARITY_TYPE,
        Han_Bus_Slave_Diff_UART_Debug_UART_STOP_BITS_NUM,
        Han_Bus_Slave_Diff_UART_Debug_UART_OVS_FACTOR,
        Han_Bus_Slave_Diff_UART_Debug_UART_IRDA_LOW_POWER,
        Han_Bus_Slave_Diff_UART_Debug_UART_MEDIAN_FILTER_ENABLE,
        Han_Bus_Slave_Diff_UART_Debug_UART_RETRY_ON_NACK,
        Han_Bus_Slave_Diff_UART_Debug_UART_IRDA_POLARITY,
        Han_Bus_Slave_Diff_UART_Debug_UART_DROP_ON_PARITY_ERR,
        Han_Bus_Slave_Diff_UART_Debug_UART_DROP_ON_FRAME_ERR,
        Han_Bus_Slave_Diff_UART_Debug_UART_WAKE_ENABLE,
        0u,
        NULL,
        0u,
        NULL,
        Han_Bus_Slave_Diff_UART_Debug_UART_MP_MODE_ENABLE,
        Han_Bus_Slave_Diff_UART_Debug_UART_MP_ACCEPT_ADDRESS,
        Han_Bus_Slave_Diff_UART_Debug_UART_MP_RX_ADDRESS,
        Han_Bus_Slave_Diff_UART_Debug_UART_MP_RX_ADDRESS_MASK,
        (uint32) Han_Bus_Slave_Diff_UART_Debug_SCB_IRQ_INTERNAL,
        Han_Bus_Slave_Diff_UART_Debug_UART_INTR_RX_MASK,
        Han_Bus_Slave_Diff_UART_Debug_UART_RX_TRIGGER_LEVEL,
        Han_Bus_Slave_Diff_UART_Debug_UART_INTR_TX_MASK,
        Han_Bus_Slave_Diff_UART_Debug_UART_TX_TRIGGER_LEVEL,
        (uint8) Han_Bus_Slave_Diff_UART_Debug_UART_BYTE_MODE_ENABLE,
        (uint8) Han_Bus_Slave_Diff_UART_Debug_UART_CTS_ENABLE,
        (uint8) Han_Bus_Slave_Diff_UART_Debug_UART_CTS_POLARITY,
        (uint8) Han_Bus_Slave_Diff_UART_Debug_UART_RTS_POLARITY,
        (uint8) Han_Bus_Slave_Diff_UART_Debug_UART_RTS_FIFO_LEVEL
    };


    /*******************************************************************************
    * Function Name: Han_Bus_Slave_Diff_UART_Debug_UartInit
    ****************************************************************************//**
    *
    *  Configures the Han_Bus_Slave_Diff_UART_Debug for UART operation.
    *
    *  This function is intended specifically to be used when the Han_Bus_Slave_Diff_UART_Debug
    *  configuration is set to Unconfigured Han_Bus_Slave_Diff_UART_Debug in the customizer.
    *  After initializing the Han_Bus_Slave_Diff_UART_Debug in UART mode using this function,
    *  the component can be enabled using the Han_Bus_Slave_Diff_UART_Debug_Start() or
    * Han_Bus_Slave_Diff_UART_Debug_Enable() function.
    *  This function uses a pointer to a structure that provides the configuration
    *  settings. This structure contains the same information that would otherwise
    *  be provided by the customizer settings.
    *
    *  \param config: pointer to a structure that contains the following list of
    *   fields. These fields match the selections available in the customizer.
    *   Refer to the customizer for further description of the settings.
    *
    *******************************************************************************/
    void Han_Bus_Slave_Diff_UART_Debug_UartInit(const Han_Bus_Slave_Diff_UART_Debug_UART_INIT_STRUCT *config)
    {
        uint32 pinsConfig;

        if (NULL == config)
        {
            CYASSERT(0u != 0u); /* Halt execution due to bad function parameter */
        }
        else
        {
            /* Get direction to configure UART pins: TX, RX or TX+RX */
            pinsConfig  = config->direction;

        #if !(Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V0 || Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1)
            /* Add RTS and CTS pins to configure */
            pinsConfig |= (0u != config->rtsRxFifoLevel) ? (Han_Bus_Slave_Diff_UART_Debug_UART_RTS_PIN_ENABLE) : (0u);
            pinsConfig |= (0u != config->enableCts)      ? (Han_Bus_Slave_Diff_UART_Debug_UART_CTS_PIN_ENABLE) : (0u);
        #endif /* !(Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V0 || Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1) */

            /* Configure pins */
            Han_Bus_Slave_Diff_UART_Debug_SetPins(Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UART, config->mode, pinsConfig);

            /* Store internal configuration */
            Han_Bus_Slave_Diff_UART_Debug_scbMode       = (uint8) Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UART;
            Han_Bus_Slave_Diff_UART_Debug_scbEnableWake = (uint8) config->enableWake;
            Han_Bus_Slave_Diff_UART_Debug_scbEnableIntr = (uint8) config->enableInterrupt;

            /* Set RX direction internal variables */
            Han_Bus_Slave_Diff_UART_Debug_rxBuffer      =         config->rxBuffer;
            Han_Bus_Slave_Diff_UART_Debug_rxDataBits    = (uint8) config->dataBits;
            Han_Bus_Slave_Diff_UART_Debug_rxBufferSize  = (uint8) config->rxBufferSize;

            /* Set TX direction internal variables */
            Han_Bus_Slave_Diff_UART_Debug_txBuffer      =         config->txBuffer;
            Han_Bus_Slave_Diff_UART_Debug_txDataBits    = (uint8) config->dataBits;
            Han_Bus_Slave_Diff_UART_Debug_txBufferSize  = (uint8) config->txBufferSize;

            /* Configure UART interface */
            if(Han_Bus_Slave_Diff_UART_Debug_UART_MODE_IRDA == config->mode)
            {
                /* OVS settings: IrDA */
                Han_Bus_Slave_Diff_UART_Debug_CTRL_REG  = ((0u != config->enableIrdaLowPower) ?
                                                (Han_Bus_Slave_Diff_UART_Debug_UART_GET_CTRL_OVS_IRDA_LP(config->oversample)) :
                                                (Han_Bus_Slave_Diff_UART_Debug_CTRL_OVS_IRDA_OVS16));
            }
            else
            {
                /* OVS settings: UART and SmartCard */
                Han_Bus_Slave_Diff_UART_Debug_CTRL_REG  = Han_Bus_Slave_Diff_UART_Debug_GET_CTRL_OVS(config->oversample);
            }

            Han_Bus_Slave_Diff_UART_Debug_CTRL_REG     |= Han_Bus_Slave_Diff_UART_Debug_GET_CTRL_BYTE_MODE  (config->enableByteMode)      |
                                             Han_Bus_Slave_Diff_UART_Debug_GET_CTRL_ADDR_ACCEPT(config->multiprocAcceptAddr) |
                                             Han_Bus_Slave_Diff_UART_Debug_CTRL_UART;

            /* Configure sub-mode: UART, SmartCard or IrDA */
            Han_Bus_Slave_Diff_UART_Debug_UART_CTRL_REG = Han_Bus_Slave_Diff_UART_Debug_GET_UART_CTRL_MODE(config->mode);

            /* Configure RX direction */
            Han_Bus_Slave_Diff_UART_Debug_UART_RX_CTRL_REG = Han_Bus_Slave_Diff_UART_Debug_GET_UART_RX_CTRL_MODE(config->stopBits)              |
                                        Han_Bus_Slave_Diff_UART_Debug_GET_UART_RX_CTRL_POLARITY(config->enableInvertedRx)          |
                                        Han_Bus_Slave_Diff_UART_Debug_GET_UART_RX_CTRL_MP_MODE(config->enableMultiproc)            |
                                        Han_Bus_Slave_Diff_UART_Debug_GET_UART_RX_CTRL_DROP_ON_PARITY_ERR(config->dropOnParityErr) |
                                        Han_Bus_Slave_Diff_UART_Debug_GET_UART_RX_CTRL_DROP_ON_FRAME_ERR(config->dropOnFrameErr);

            if(Han_Bus_Slave_Diff_UART_Debug_UART_PARITY_NONE != config->parity)
            {
               Han_Bus_Slave_Diff_UART_Debug_UART_RX_CTRL_REG |= Han_Bus_Slave_Diff_UART_Debug_GET_UART_RX_CTRL_PARITY(config->parity) |
                                                    Han_Bus_Slave_Diff_UART_Debug_UART_RX_CTRL_PARITY_ENABLED;
            }

            Han_Bus_Slave_Diff_UART_Debug_RX_CTRL_REG      = Han_Bus_Slave_Diff_UART_Debug_GET_RX_CTRL_DATA_WIDTH(config->dataBits)       |
                                                Han_Bus_Slave_Diff_UART_Debug_GET_RX_CTRL_MEDIAN(config->enableMedianFilter) |
                                                Han_Bus_Slave_Diff_UART_Debug_GET_UART_RX_CTRL_ENABLED(config->direction);

            Han_Bus_Slave_Diff_UART_Debug_RX_FIFO_CTRL_REG = Han_Bus_Slave_Diff_UART_Debug_GET_RX_FIFO_CTRL_TRIGGER_LEVEL(config->rxTriggerLevel);

            /* Configure MP address */
            Han_Bus_Slave_Diff_UART_Debug_RX_MATCH_REG     = Han_Bus_Slave_Diff_UART_Debug_GET_RX_MATCH_ADDR(config->multiprocAddr) |
                                                Han_Bus_Slave_Diff_UART_Debug_GET_RX_MATCH_MASK(config->multiprocAddrMask);

            /* Configure RX direction */
            Han_Bus_Slave_Diff_UART_Debug_UART_TX_CTRL_REG = Han_Bus_Slave_Diff_UART_Debug_GET_UART_TX_CTRL_MODE(config->stopBits) |
                                                Han_Bus_Slave_Diff_UART_Debug_GET_UART_TX_CTRL_RETRY_NACK(config->enableRetryNack);

            if(Han_Bus_Slave_Diff_UART_Debug_UART_PARITY_NONE != config->parity)
            {
               Han_Bus_Slave_Diff_UART_Debug_UART_TX_CTRL_REG |= Han_Bus_Slave_Diff_UART_Debug_GET_UART_TX_CTRL_PARITY(config->parity) |
                                                    Han_Bus_Slave_Diff_UART_Debug_UART_TX_CTRL_PARITY_ENABLED;
            }

            Han_Bus_Slave_Diff_UART_Debug_TX_CTRL_REG      = Han_Bus_Slave_Diff_UART_Debug_GET_TX_CTRL_DATA_WIDTH(config->dataBits)    |
                                                Han_Bus_Slave_Diff_UART_Debug_GET_UART_TX_CTRL_ENABLED(config->direction);

            Han_Bus_Slave_Diff_UART_Debug_TX_FIFO_CTRL_REG = Han_Bus_Slave_Diff_UART_Debug_GET_TX_FIFO_CTRL_TRIGGER_LEVEL(config->txTriggerLevel);

        #if !(Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V0 || Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1)
            Han_Bus_Slave_Diff_UART_Debug_UART_FLOW_CTRL_REG = Han_Bus_Slave_Diff_UART_Debug_GET_UART_FLOW_CTRL_CTS_ENABLE(config->enableCts) | \
                                            Han_Bus_Slave_Diff_UART_Debug_GET_UART_FLOW_CTRL_CTS_POLARITY (config->ctsPolarity)  | \
                                            Han_Bus_Slave_Diff_UART_Debug_GET_UART_FLOW_CTRL_RTS_POLARITY (config->rtsPolarity)  | \
                                            Han_Bus_Slave_Diff_UART_Debug_GET_UART_FLOW_CTRL_TRIGGER_LEVEL(config->rtsRxFifoLevel);
        #endif /* !(Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V0 || Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1) */

            /* Configure interrupt with UART handler but do not enable it */
            CyIntDisable    (Han_Bus_Slave_Diff_UART_Debug_ISR_NUMBER);
            CyIntSetPriority(Han_Bus_Slave_Diff_UART_Debug_ISR_NUMBER, Han_Bus_Slave_Diff_UART_Debug_ISR_PRIORITY);
            (void) CyIntSetVector(Han_Bus_Slave_Diff_UART_Debug_ISR_NUMBER, &Han_Bus_Slave_Diff_UART_Debug_SPI_UART_ISR);

            /* Configure WAKE interrupt */
        #if(Han_Bus_Slave_Diff_UART_Debug_UART_RX_WAKEUP_IRQ)
            CyIntDisable    (Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_ISR_NUMBER);
            CyIntSetPriority(Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_ISR_NUMBER, Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_ISR_PRIORITY);
            (void) CyIntSetVector(Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_ISR_NUMBER, &Han_Bus_Slave_Diff_UART_Debug_UART_WAKEUP_ISR);
        #endif /* (Han_Bus_Slave_Diff_UART_Debug_UART_RX_WAKEUP_IRQ) */

            /* Configure interrupt sources */
            Han_Bus_Slave_Diff_UART_Debug_INTR_I2C_EC_MASK_REG = Han_Bus_Slave_Diff_UART_Debug_NO_INTR_SOURCES;
            Han_Bus_Slave_Diff_UART_Debug_INTR_SPI_EC_MASK_REG = Han_Bus_Slave_Diff_UART_Debug_NO_INTR_SOURCES;
            Han_Bus_Slave_Diff_UART_Debug_INTR_SLAVE_MASK_REG  = Han_Bus_Slave_Diff_UART_Debug_NO_INTR_SOURCES;
            Han_Bus_Slave_Diff_UART_Debug_INTR_MASTER_MASK_REG = Han_Bus_Slave_Diff_UART_Debug_NO_INTR_SOURCES;
            Han_Bus_Slave_Diff_UART_Debug_INTR_RX_MASK_REG     = config->rxInterruptMask;
            Han_Bus_Slave_Diff_UART_Debug_INTR_TX_MASK_REG     = config->txInterruptMask;
        
            /* Configure TX interrupt sources to restore. */
            Han_Bus_Slave_Diff_UART_Debug_IntrTxMask = LO16(Han_Bus_Slave_Diff_UART_Debug_INTR_TX_MASK_REG);

            /* Clear RX buffer indexes */
            Han_Bus_Slave_Diff_UART_Debug_rxBufferHead     = 0u;
            Han_Bus_Slave_Diff_UART_Debug_rxBufferTail     = 0u;
            Han_Bus_Slave_Diff_UART_Debug_rxBufferOverflow = 0u;

            /* Clear TX buffer indexes */
            Han_Bus_Slave_Diff_UART_Debug_txBufferHead = 0u;
            Han_Bus_Slave_Diff_UART_Debug_txBufferTail = 0u;
        }
    }

#else

    /*******************************************************************************
    * Function Name: Han_Bus_Slave_Diff_UART_Debug_UartInit
    ****************************************************************************//**
    *
    *  Configures the SCB for the UART operation.
    *
    *******************************************************************************/
    void Han_Bus_Slave_Diff_UART_Debug_UartInit(void)
    {
        /* Configure UART interface */
        Han_Bus_Slave_Diff_UART_Debug_CTRL_REG = Han_Bus_Slave_Diff_UART_Debug_UART_DEFAULT_CTRL;

        /* Configure sub-mode: UART, SmartCard or IrDA */
        Han_Bus_Slave_Diff_UART_Debug_UART_CTRL_REG = Han_Bus_Slave_Diff_UART_Debug_UART_DEFAULT_UART_CTRL;

        /* Configure RX direction */
        Han_Bus_Slave_Diff_UART_Debug_UART_RX_CTRL_REG = Han_Bus_Slave_Diff_UART_Debug_UART_DEFAULT_UART_RX_CTRL;
        Han_Bus_Slave_Diff_UART_Debug_RX_CTRL_REG      = Han_Bus_Slave_Diff_UART_Debug_UART_DEFAULT_RX_CTRL;
        Han_Bus_Slave_Diff_UART_Debug_RX_FIFO_CTRL_REG = Han_Bus_Slave_Diff_UART_Debug_UART_DEFAULT_RX_FIFO_CTRL;
        Han_Bus_Slave_Diff_UART_Debug_RX_MATCH_REG     = Han_Bus_Slave_Diff_UART_Debug_UART_DEFAULT_RX_MATCH_REG;

        /* Configure TX direction */
        Han_Bus_Slave_Diff_UART_Debug_UART_TX_CTRL_REG = Han_Bus_Slave_Diff_UART_Debug_UART_DEFAULT_UART_TX_CTRL;
        Han_Bus_Slave_Diff_UART_Debug_TX_CTRL_REG      = Han_Bus_Slave_Diff_UART_Debug_UART_DEFAULT_TX_CTRL;
        Han_Bus_Slave_Diff_UART_Debug_TX_FIFO_CTRL_REG = Han_Bus_Slave_Diff_UART_Debug_UART_DEFAULT_TX_FIFO_CTRL;

    #if !(Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V0 || Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1)
        Han_Bus_Slave_Diff_UART_Debug_UART_FLOW_CTRL_REG = Han_Bus_Slave_Diff_UART_Debug_UART_DEFAULT_FLOW_CTRL;
    #endif /* !(Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V0 || Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1) */

        /* Configure interrupt with UART handler but do not enable it */
    #if(Han_Bus_Slave_Diff_UART_Debug_SCB_IRQ_INTERNAL)
        CyIntDisable    (Han_Bus_Slave_Diff_UART_Debug_ISR_NUMBER);
        CyIntSetPriority(Han_Bus_Slave_Diff_UART_Debug_ISR_NUMBER, Han_Bus_Slave_Diff_UART_Debug_ISR_PRIORITY);
        (void) CyIntSetVector(Han_Bus_Slave_Diff_UART_Debug_ISR_NUMBER, &Han_Bus_Slave_Diff_UART_Debug_SPI_UART_ISR);
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_IRQ_INTERNAL) */

        /* Configure WAKE interrupt */
    #if(Han_Bus_Slave_Diff_UART_Debug_UART_RX_WAKEUP_IRQ)
        CyIntDisable    (Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_ISR_NUMBER);
        CyIntSetPriority(Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_ISR_NUMBER, Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_ISR_PRIORITY);
        (void) CyIntSetVector(Han_Bus_Slave_Diff_UART_Debug_RX_WAKE_ISR_NUMBER, &Han_Bus_Slave_Diff_UART_Debug_UART_WAKEUP_ISR);
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_UART_RX_WAKEUP_IRQ) */

        /* Configure interrupt sources */
        Han_Bus_Slave_Diff_UART_Debug_INTR_I2C_EC_MASK_REG = Han_Bus_Slave_Diff_UART_Debug_UART_DEFAULT_INTR_I2C_EC_MASK;
        Han_Bus_Slave_Diff_UART_Debug_INTR_SPI_EC_MASK_REG = Han_Bus_Slave_Diff_UART_Debug_UART_DEFAULT_INTR_SPI_EC_MASK;
        Han_Bus_Slave_Diff_UART_Debug_INTR_SLAVE_MASK_REG  = Han_Bus_Slave_Diff_UART_Debug_UART_DEFAULT_INTR_SLAVE_MASK;
        Han_Bus_Slave_Diff_UART_Debug_INTR_MASTER_MASK_REG = Han_Bus_Slave_Diff_UART_Debug_UART_DEFAULT_INTR_MASTER_MASK;
        Han_Bus_Slave_Diff_UART_Debug_INTR_RX_MASK_REG     = Han_Bus_Slave_Diff_UART_Debug_UART_DEFAULT_INTR_RX_MASK;
        Han_Bus_Slave_Diff_UART_Debug_INTR_TX_MASK_REG     = Han_Bus_Slave_Diff_UART_Debug_UART_DEFAULT_INTR_TX_MASK;
    
        /* Configure TX interrupt sources to restore. */
        Han_Bus_Slave_Diff_UART_Debug_IntrTxMask = LO16(Han_Bus_Slave_Diff_UART_Debug_INTR_TX_MASK_REG);

    #if(Han_Bus_Slave_Diff_UART_Debug_INTERNAL_RX_SW_BUFFER_CONST)
        Han_Bus_Slave_Diff_UART_Debug_rxBufferHead     = 0u;
        Han_Bus_Slave_Diff_UART_Debug_rxBufferTail     = 0u;
        Han_Bus_Slave_Diff_UART_Debug_rxBufferOverflow = 0u;
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_INTERNAL_RX_SW_BUFFER_CONST) */

    #if(Han_Bus_Slave_Diff_UART_Debug_INTERNAL_TX_SW_BUFFER_CONST)
        Han_Bus_Slave_Diff_UART_Debug_txBufferHead = 0u;
        Han_Bus_Slave_Diff_UART_Debug_txBufferTail = 0u;
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_INTERNAL_TX_SW_BUFFER_CONST) */
    }
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG) */


/*******************************************************************************
* Function Name: Han_Bus_Slave_Diff_UART_Debug_UartPostEnable
****************************************************************************//**
*
*  Restores HSIOM settings for the UART output pins (TX and/or RTS) to be
*  controlled by the SCB UART.
*
*******************************************************************************/
void Han_Bus_Slave_Diff_UART_Debug_UartPostEnable(void)
{
#if (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG)
    #if (Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN)
        if (Han_Bus_Slave_Diff_UART_Debug_CHECK_TX_SDA_MISO_PIN_USED)
        {
            /* Set SCB UART to drive the output pin */
            Han_Bus_Slave_Diff_UART_Debug_SET_HSIOM_SEL(Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_HSIOM_REG, Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_HSIOM_MASK,
                                           Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_HSIOM_POS, Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_HSIOM_SEL_UART);
        }
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN_PIN) */

    #if !(Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V0 || Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1)
        #if (Han_Bus_Slave_Diff_UART_Debug_SS0_PIN)
            if (Han_Bus_Slave_Diff_UART_Debug_CHECK_SS0_PIN_USED)
            {
                /* Set SCB UART to drive the output pin */
                Han_Bus_Slave_Diff_UART_Debug_SET_HSIOM_SEL(Han_Bus_Slave_Diff_UART_Debug_SS0_HSIOM_REG, Han_Bus_Slave_Diff_UART_Debug_SS0_HSIOM_MASK,
                                               Han_Bus_Slave_Diff_UART_Debug_SS0_HSIOM_POS, Han_Bus_Slave_Diff_UART_Debug_SS0_HSIOM_SEL_UART);
            }
        #endif /* (Han_Bus_Slave_Diff_UART_Debug_SS0_PIN) */
    #endif /* !(Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V0 || Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1) */

#else
    #if (Han_Bus_Slave_Diff_UART_Debug_UART_TX_PIN)
         /* Set SCB UART to drive the output pin */
        Han_Bus_Slave_Diff_UART_Debug_SET_HSIOM_SEL(Han_Bus_Slave_Diff_UART_Debug_TX_HSIOM_REG, Han_Bus_Slave_Diff_UART_Debug_TX_HSIOM_MASK,
                                       Han_Bus_Slave_Diff_UART_Debug_TX_HSIOM_POS, Han_Bus_Slave_Diff_UART_Debug_TX_HSIOM_SEL_UART);
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_UART_TX_PIN) */

    #if (Han_Bus_Slave_Diff_UART_Debug_UART_RTS_PIN)
        /* Set SCB UART to drive the output pin */
        Han_Bus_Slave_Diff_UART_Debug_SET_HSIOM_SEL(Han_Bus_Slave_Diff_UART_Debug_RTS_HSIOM_REG, Han_Bus_Slave_Diff_UART_Debug_RTS_HSIOM_MASK,
                                       Han_Bus_Slave_Diff_UART_Debug_RTS_HSIOM_POS, Han_Bus_Slave_Diff_UART_Debug_RTS_HSIOM_SEL_UART);
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_UART_RTS_PIN) */
#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG) */

    /* Restore TX interrupt sources. */
    Han_Bus_Slave_Diff_UART_Debug_SetTxInterruptMode(Han_Bus_Slave_Diff_UART_Debug_IntrTxMask);
}


/*******************************************************************************
* Function Name: Han_Bus_Slave_Diff_UART_Debug_UartStop
****************************************************************************//**
*
*  Changes the HSIOM settings for the UART output pins (TX and/or RTS) to keep
*  them inactive after the block is disabled. The output pins are controlled by
*  the GPIO data register. Also, the function disables the skip start feature
*  to not cause it to trigger after the component is enabled.
*
*******************************************************************************/
void Han_Bus_Slave_Diff_UART_Debug_UartStop(void)
{
#if(Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG)
    #if (Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN)
        if (Han_Bus_Slave_Diff_UART_Debug_CHECK_TX_SDA_MISO_PIN_USED)
        {
            /* Set GPIO to drive output pin */
            Han_Bus_Slave_Diff_UART_Debug_SET_HSIOM_SEL(Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_HSIOM_REG, Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_HSIOM_MASK,
                                           Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_HSIOM_POS, Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_HSIOM_SEL_GPIO);
        }
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_TX_SDA_MISO_PIN_PIN) */

    #if !(Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V0 || Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1)
        #if (Han_Bus_Slave_Diff_UART_Debug_SS0_PIN)
            if (Han_Bus_Slave_Diff_UART_Debug_CHECK_SS0_PIN_USED)
            {
                /* Set output pin state after block is disabled */
                Han_Bus_Slave_Diff_UART_Debug_spi_ss0_Write(Han_Bus_Slave_Diff_UART_Debug_GET_UART_RTS_INACTIVE);

                /* Set GPIO to drive output pin */
                Han_Bus_Slave_Diff_UART_Debug_SET_HSIOM_SEL(Han_Bus_Slave_Diff_UART_Debug_SS0_HSIOM_REG, Han_Bus_Slave_Diff_UART_Debug_SS0_HSIOM_MASK,
                                               Han_Bus_Slave_Diff_UART_Debug_SS0_HSIOM_POS, Han_Bus_Slave_Diff_UART_Debug_SS0_HSIOM_SEL_GPIO);
            }
        #endif /* (Han_Bus_Slave_Diff_UART_Debug_SS0_PIN) */
    #endif /* !(Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V0 || Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1) */

#else
    #if (Han_Bus_Slave_Diff_UART_Debug_UART_TX_PIN)
        /* Set GPIO to drive output pin */
        Han_Bus_Slave_Diff_UART_Debug_SET_HSIOM_SEL(Han_Bus_Slave_Diff_UART_Debug_TX_HSIOM_REG, Han_Bus_Slave_Diff_UART_Debug_TX_HSIOM_MASK,
                                       Han_Bus_Slave_Diff_UART_Debug_TX_HSIOM_POS, Han_Bus_Slave_Diff_UART_Debug_TX_HSIOM_SEL_GPIO);
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_UART_TX_PIN) */

    #if (Han_Bus_Slave_Diff_UART_Debug_UART_RTS_PIN)
        /* Set output pin state after block is disabled */
        Han_Bus_Slave_Diff_UART_Debug_rts_Write(Han_Bus_Slave_Diff_UART_Debug_GET_UART_RTS_INACTIVE);

        /* Set GPIO to drive output pin */
        Han_Bus_Slave_Diff_UART_Debug_SET_HSIOM_SEL(Han_Bus_Slave_Diff_UART_Debug_RTS_HSIOM_REG, Han_Bus_Slave_Diff_UART_Debug_RTS_HSIOM_MASK,
                                       Han_Bus_Slave_Diff_UART_Debug_RTS_HSIOM_POS, Han_Bus_Slave_Diff_UART_Debug_RTS_HSIOM_SEL_GPIO);
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_UART_RTS_PIN) */

#endif /* (Han_Bus_Slave_Diff_UART_Debug_SCB_MODE_UNCONFIG_CONST_CFG) */

#if (Han_Bus_Slave_Diff_UART_Debug_UART_WAKE_ENABLE_CONST)
    /* Disable skip start feature used for wakeup */
    Han_Bus_Slave_Diff_UART_Debug_UART_RX_CTRL_REG &= (uint32) ~Han_Bus_Slave_Diff_UART_Debug_UART_RX_CTRL_SKIP_START;
#endif /* (Han_Bus_Slave_Diff_UART_Debug_UART_WAKE_ENABLE_CONST) */

    /* Store TX interrupt sources (exclude level triggered). */
    Han_Bus_Slave_Diff_UART_Debug_IntrTxMask = LO16(Han_Bus_Slave_Diff_UART_Debug_GetTxInterruptMode() & Han_Bus_Slave_Diff_UART_Debug_INTR_UART_TX_RESTORE);
}


/*******************************************************************************
* Function Name: Han_Bus_Slave_Diff_UART_Debug_UartSetRxAddress
****************************************************************************//**
*
*  Sets the hardware detectable receiver address for the UART in the
*  Multiprocessor mode.
*
*  \param address: Address for hardware address detection.
*
*******************************************************************************/
void Han_Bus_Slave_Diff_UART_Debug_UartSetRxAddress(uint32 address)
{
     uint32 matchReg;

    matchReg = Han_Bus_Slave_Diff_UART_Debug_RX_MATCH_REG;

    matchReg &= ((uint32) ~Han_Bus_Slave_Diff_UART_Debug_RX_MATCH_ADDR_MASK); /* Clear address bits */
    matchReg |= ((uint32)  (address & Han_Bus_Slave_Diff_UART_Debug_RX_MATCH_ADDR_MASK)); /* Set address  */

    Han_Bus_Slave_Diff_UART_Debug_RX_MATCH_REG = matchReg;
}


/*******************************************************************************
* Function Name: Han_Bus_Slave_Diff_UART_Debug_UartSetRxAddressMask
****************************************************************************//**
*
*  Sets the hardware address mask for the UART in the Multiprocessor mode.
*
*  \param addressMask: Address mask.
*   - Bit value 0  excludes bit from address comparison.
*   - Bit value 1  the bit needs to match with the corresponding bit
*     of the address.
*
*******************************************************************************/
void Han_Bus_Slave_Diff_UART_Debug_UartSetRxAddressMask(uint32 addressMask)
{
    uint32 matchReg;

    matchReg = Han_Bus_Slave_Diff_UART_Debug_RX_MATCH_REG;

    matchReg &= ((uint32) ~Han_Bus_Slave_Diff_UART_Debug_RX_MATCH_MASK_MASK); /* Clear address mask bits */
    matchReg |= ((uint32) (addressMask << Han_Bus_Slave_Diff_UART_Debug_RX_MATCH_MASK_POS));

    Han_Bus_Slave_Diff_UART_Debug_RX_MATCH_REG = matchReg;
}


#if(Han_Bus_Slave_Diff_UART_Debug_UART_RX_DIRECTION)
    /*******************************************************************************
    * Function Name: Han_Bus_Slave_Diff_UART_Debug_UartGetChar
    ****************************************************************************//**
    *
    *  Retrieves next data element from receive buffer.
    *  This function is designed for ASCII characters and returns a char where
    *  1 to 255 are valid characters and 0 indicates an error occurred or no data
    *  is present.
    *  - RX software buffer is disabled: Returns data element retrieved from RX
    *    FIFO.
    *  - RX software buffer is enabled: Returns data element from the software
    *    receive buffer.
    *
    *  \return
    *   Next data element from the receive buffer. ASCII character values from
    *   1 to 255 are valid. A returned zero signifies an error condition or no
    *   data available.
    *
    *  \sideeffect
    *   The errors bits may not correspond with reading characters due to
    *   RX FIFO and software buffer usage.
    *   RX software buffer is enabled: The internal software buffer overflow
    *   is not treated as an error condition.
    *   Check Han_Bus_Slave_Diff_UART_Debug_rxBufferOverflow to capture that error condition.
    *
    *******************************************************************************/
    uint32 Han_Bus_Slave_Diff_UART_Debug_UartGetChar(void)
    {
        uint32 rxData = 0u;

        /* Reads data only if there is data to read */
        if (0u != Han_Bus_Slave_Diff_UART_Debug_SpiUartGetRxBufferSize())
        {
            rxData = Han_Bus_Slave_Diff_UART_Debug_SpiUartReadRxData();
        }

        if (Han_Bus_Slave_Diff_UART_Debug_CHECK_INTR_RX(Han_Bus_Slave_Diff_UART_Debug_INTR_RX_ERR))
        {
            rxData = 0u; /* Error occurred: returns zero */
            Han_Bus_Slave_Diff_UART_Debug_ClearRxInterruptSource(Han_Bus_Slave_Diff_UART_Debug_INTR_RX_ERR);
        }

        return (rxData);
    }


    /*******************************************************************************
    * Function Name: Han_Bus_Slave_Diff_UART_Debug_UartGetByte
    ****************************************************************************//**
    *
    *  Retrieves the next data element from the receive buffer, returns the
    *  received byte and error condition.
    *   - The RX software buffer is disabled: returns the data element retrieved
    *     from the RX FIFO. Undefined data will be returned if the RX FIFO is
    *     empty.
    *   - The RX software buffer is enabled: returns data element from the
    *     software receive buffer.
    *
    *  \return
    *   Bits 7-0 contain the next data element from the receive buffer and
    *   other bits contain the error condition.
    *   - Han_Bus_Slave_Diff_UART_Debug_UART_RX_OVERFLOW - Attempt to write to a full
    *     receiver FIFO.
    *   - Han_Bus_Slave_Diff_UART_Debug_UART_RX_UNDERFLOW	Attempt to read from an empty
    *     receiver FIFO.
    *   - Han_Bus_Slave_Diff_UART_Debug_UART_RX_FRAME_ERROR - UART framing error detected.
    *   - Han_Bus_Slave_Diff_UART_Debug_UART_RX_PARITY_ERROR - UART parity error detected.
    *
    *  \sideeffect
    *   The errors bits may not correspond with reading characters due to
    *   RX FIFO and software buffer usage.
    *   RX software buffer is enabled: The internal software buffer overflow
    *   is not treated as an error condition.
    *   Check Han_Bus_Slave_Diff_UART_Debug_rxBufferOverflow to capture that error condition.
    *
    *******************************************************************************/
    uint32 Han_Bus_Slave_Diff_UART_Debug_UartGetByte(void)
    {
        uint32 rxData;
        uint32 tmpStatus;

        #if (Han_Bus_Slave_Diff_UART_Debug_CHECK_RX_SW_BUFFER)
        {
            Han_Bus_Slave_Diff_UART_Debug_DisableInt();
        }
        #endif

        if (0u != Han_Bus_Slave_Diff_UART_Debug_SpiUartGetRxBufferSize())
        {
            /* Enables interrupt to receive more bytes: at least one byte is in
            * buffer.
            */
            #if (Han_Bus_Slave_Diff_UART_Debug_CHECK_RX_SW_BUFFER)
            {
                Han_Bus_Slave_Diff_UART_Debug_EnableInt();
            }
            #endif

            /* Get received byte */
            rxData = Han_Bus_Slave_Diff_UART_Debug_SpiUartReadRxData();
        }
        else
        {
            /* Reads a byte directly from RX FIFO: underflow is raised in the
            * case of empty. Otherwise the first received byte will be read.
            */
            rxData = Han_Bus_Slave_Diff_UART_Debug_RX_FIFO_RD_REG;


            /* Enables interrupt to receive more bytes. */
            #if (Han_Bus_Slave_Diff_UART_Debug_CHECK_RX_SW_BUFFER)
            {

                /* The byte has been read from RX FIFO. Clear RX interrupt to
                * not involve interrupt handler when RX FIFO is empty.
                */
                Han_Bus_Slave_Diff_UART_Debug_ClearRxInterruptSource(Han_Bus_Slave_Diff_UART_Debug_INTR_RX_NOT_EMPTY);

                Han_Bus_Slave_Diff_UART_Debug_EnableInt();
            }
            #endif
        }

        /* Get and clear RX error mask */
        tmpStatus = (Han_Bus_Slave_Diff_UART_Debug_GetRxInterruptSource() & Han_Bus_Slave_Diff_UART_Debug_INTR_RX_ERR);
        Han_Bus_Slave_Diff_UART_Debug_ClearRxInterruptSource(Han_Bus_Slave_Diff_UART_Debug_INTR_RX_ERR);

        /* Puts together data and error status:
        * MP mode and accept address: 9th bit is set to notify mark.
        */
        rxData |= ((uint32) (tmpStatus << 8u));

        return (rxData);
    }


    #if !(Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V0 || Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1)
        /*******************************************************************************
        * Function Name: Han_Bus_Slave_Diff_UART_Debug_UartSetRtsPolarity
        ****************************************************************************//**
        *
        *  Sets active polarity of RTS output signal.
        *  Only available for PSoC 4100 BLE / PSoC 4200 BLE / PSoC 4100M / PSoC 4200M /
        *  PSoC 4200L / PSoC 4000S / PSoC 4100S / PSoC Analog Coprocessor devices.
        *
        *  \param polarity: Active polarity of RTS output signal.
        *   - Han_Bus_Slave_Diff_UART_Debug_UART_RTS_ACTIVE_LOW  - RTS signal is active low.
        *   - Han_Bus_Slave_Diff_UART_Debug_UART_RTS_ACTIVE_HIGH - RTS signal is active high.
        *
        *******************************************************************************/
        void Han_Bus_Slave_Diff_UART_Debug_UartSetRtsPolarity(uint32 polarity)
        {
            if(0u != polarity)
            {
                Han_Bus_Slave_Diff_UART_Debug_UART_FLOW_CTRL_REG |= (uint32)  Han_Bus_Slave_Diff_UART_Debug_UART_FLOW_CTRL_RTS_POLARITY;
            }
            else
            {
                Han_Bus_Slave_Diff_UART_Debug_UART_FLOW_CTRL_REG &= (uint32) ~Han_Bus_Slave_Diff_UART_Debug_UART_FLOW_CTRL_RTS_POLARITY;
            }
        }


        /*******************************************************************************
        * Function Name: Han_Bus_Slave_Diff_UART_Debug_UartSetRtsFifoLevel
        ****************************************************************************//**
        *
        *  Sets level in the RX FIFO for RTS signal activation.
        *  While the RX FIFO has fewer entries than the RX FIFO level the RTS signal
        *  remains active, otherwise the RTS signal becomes inactive.
        *  Only available for PSoC 4100 BLE / PSoC 4200 BLE / PSoC 4100M / PSoC 4200M /
        *  PSoC 4200L / PSoC 4000S / PSoC 4100S / PSoC Analog Coprocessor devices.
        *
        *  \param level: Level in the RX FIFO for RTS signal activation.
        *   The range of valid level values is between 0 and RX FIFO depth - 1.
        *   Setting level value to 0 disables RTS signal activation.
        *
        *******************************************************************************/
        void Han_Bus_Slave_Diff_UART_Debug_UartSetRtsFifoLevel(uint32 level)
        {
            uint32 uartFlowCtrl;

            uartFlowCtrl = Han_Bus_Slave_Diff_UART_Debug_UART_FLOW_CTRL_REG;

            uartFlowCtrl &= ((uint32) ~Han_Bus_Slave_Diff_UART_Debug_UART_FLOW_CTRL_TRIGGER_LEVEL_MASK); /* Clear level mask bits */
            uartFlowCtrl |= ((uint32) (Han_Bus_Slave_Diff_UART_Debug_UART_FLOW_CTRL_TRIGGER_LEVEL_MASK & level));

            Han_Bus_Slave_Diff_UART_Debug_UART_FLOW_CTRL_REG = uartFlowCtrl;
        }
    #endif /* !(Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V0 || Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1) */

#endif /* (Han_Bus_Slave_Diff_UART_Debug_UART_RX_DIRECTION) */


#if(Han_Bus_Slave_Diff_UART_Debug_UART_TX_DIRECTION)
    /*******************************************************************************
    * Function Name: Han_Bus_Slave_Diff_UART_Debug_UartPutString
    ****************************************************************************//**
    *
    *  Places a NULL terminated string in the transmit buffer to be sent at the
    *  next available bus time.
    *  This function is blocking and waits until there is a space available to put
    *  requested data in transmit buffer.
    *
    *  \param string: pointer to the null terminated string array to be placed in the
    *   transmit buffer.
    *
    *******************************************************************************/
    void Han_Bus_Slave_Diff_UART_Debug_UartPutString(const char8 string[])
    {
        uint32 bufIndex;

        bufIndex = 0u;

        /* Blocks the control flow until all data has been sent */
        while(string[bufIndex] != ((char8) 0))
        {
            Han_Bus_Slave_Diff_UART_Debug_UartPutChar((uint32) string[bufIndex]);
            bufIndex++;
        }
    }


    /*******************************************************************************
    * Function Name: Han_Bus_Slave_Diff_UART_Debug_UartPutCRLF
    ****************************************************************************//**
    *
    *  Places byte of data followed by a carriage return (0x0D) and line feed
    *  (0x0A) in the transmit buffer.
    *  This function is blocking and waits until there is a space available to put
    *  all requested data in transmit buffer.
    *
    *  \param txDataByte: the data to be transmitted.
    *
    *******************************************************************************/
    void Han_Bus_Slave_Diff_UART_Debug_UartPutCRLF(uint32 txDataByte)
    {
        Han_Bus_Slave_Diff_UART_Debug_UartPutChar(txDataByte);  /* Blocks control flow until all data has been sent */
        Han_Bus_Slave_Diff_UART_Debug_UartPutChar(0x0Du);       /* Blocks control flow until all data has been sent */
        Han_Bus_Slave_Diff_UART_Debug_UartPutChar(0x0Au);       /* Blocks control flow until all data has been sent */
    }


    #if !(Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V0 || Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1)
        /*******************************************************************************
        * Function Name: Han_Bus_Slave_Diff_UART_DebugSCB_UartEnableCts
        ****************************************************************************//**
        *
        *  Enables usage of CTS input signal by the UART transmitter.
        *  Only available for PSoC 4100 BLE / PSoC 4200 BLE / PSoC 4100M / PSoC 4200M /
        *  PSoC 4200L / PSoC 4000S / PSoC 4100S / PSoC Analog Coprocessor devices.
        *
        *******************************************************************************/
        void Han_Bus_Slave_Diff_UART_Debug_UartEnableCts(void)
        {
            Han_Bus_Slave_Diff_UART_Debug_UART_FLOW_CTRL_REG |= (uint32)  Han_Bus_Slave_Diff_UART_Debug_UART_FLOW_CTRL_CTS_ENABLE;
        }


        /*******************************************************************************
        * Function Name: Han_Bus_Slave_Diff_UART_Debug_UartDisableCts
        ****************************************************************************//**
        *
        *  Disables usage of CTS input signal by the UART transmitter.
        *  Only available for PSoC 4100 BLE / PSoC 4200 BLE / PSoC 4100M / PSoC 4200M /
        *  PSoC 4200L / PSoC 4000S / PSoC 4100S / PSoC Analog Coprocessor devices.
        *
        *******************************************************************************/
        void Han_Bus_Slave_Diff_UART_Debug_UartDisableCts(void)
        {
            Han_Bus_Slave_Diff_UART_Debug_UART_FLOW_CTRL_REG &= (uint32) ~Han_Bus_Slave_Diff_UART_Debug_UART_FLOW_CTRL_CTS_ENABLE;
        }


        /*******************************************************************************
        * Function Name: Han_Bus_Slave_Diff_UART_Debug_UartSetCtsPolarity
        ****************************************************************************//**
        *
        *  Sets active polarity of CTS input signal.
        *  Only available for PSoC 4100 BLE / PSoC 4200 BLE / PSoC 4100M / PSoC 4200M /
        *  PSoC 4200L / PSoC 4000S / PSoC 4100S / PSoC Analog Coprocessor devices.
        *
        *  \param polarity: Active polarity of CTS output signal.
        *   - Han_Bus_Slave_Diff_UART_Debug_UART_CTS_ACTIVE_LOW  - CTS signal is active low.
        *   - Han_Bus_Slave_Diff_UART_Debug_UART_CTS_ACTIVE_HIGH - CTS signal is active high.
        *
        *******************************************************************************/
        void Han_Bus_Slave_Diff_UART_Debug_UartSetCtsPolarity(uint32 polarity)
        {
            if (0u != polarity)
            {
                Han_Bus_Slave_Diff_UART_Debug_UART_FLOW_CTRL_REG |= (uint32)  Han_Bus_Slave_Diff_UART_Debug_UART_FLOW_CTRL_CTS_POLARITY;
            }
            else
            {
                Han_Bus_Slave_Diff_UART_Debug_UART_FLOW_CTRL_REG &= (uint32) ~Han_Bus_Slave_Diff_UART_Debug_UART_FLOW_CTRL_CTS_POLARITY;
            }
        }
    #endif /* !(Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V0 || Han_Bus_Slave_Diff_UART_Debug_CY_SCBIP_V1) */

#endif /* (Han_Bus_Slave_Diff_UART_Debug_UART_TX_DIRECTION) */


#if (Han_Bus_Slave_Diff_UART_Debug_UART_WAKE_ENABLE_CONST)
    /*******************************************************************************
    * Function Name: Han_Bus_Slave_Diff_UART_Debug_UartSaveConfig
    ****************************************************************************//**
    *
    *  Clears and enables an interrupt on a falling edge of the Rx input. The GPIO
    *  interrupt does not track in the active mode, therefore requires to be 
    *  cleared by this API.
    *
    *******************************************************************************/
    void Han_Bus_Slave_Diff_UART_Debug_UartSaveConfig(void)
    {
    #if (Han_Bus_Slave_Diff_UART_Debug_UART_RX_WAKEUP_IRQ)
        /* Set SKIP_START if requested (set by default). */
        if (0u != Han_Bus_Slave_Diff_UART_Debug_skipStart)
        {
            Han_Bus_Slave_Diff_UART_Debug_UART_RX_CTRL_REG |= (uint32)  Han_Bus_Slave_Diff_UART_Debug_UART_RX_CTRL_SKIP_START;
        }
        else
        {
            Han_Bus_Slave_Diff_UART_Debug_UART_RX_CTRL_REG &= (uint32) ~Han_Bus_Slave_Diff_UART_Debug_UART_RX_CTRL_SKIP_START;
        }
        
        /* Clear RX GPIO interrupt status and pending interrupt in NVIC because
        * falling edge on RX line occurs while UART communication in active mode.
        * Enable interrupt: next interrupt trigger should wakeup device.
        */
        Han_Bus_Slave_Diff_UART_Debug_CLEAR_UART_RX_WAKE_INTR;
        Han_Bus_Slave_Diff_UART_Debug_RxWakeClearPendingInt();
        Han_Bus_Slave_Diff_UART_Debug_RxWakeEnableInt();
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_UART_RX_WAKEUP_IRQ) */
    }


    /*******************************************************************************
    * Function Name: Han_Bus_Slave_Diff_UART_Debug_UartRestoreConfig
    ****************************************************************************//**
    *
    *  Disables the RX GPIO interrupt. Until this function is called the interrupt
    *  remains active and triggers on every falling edge of the UART RX line.
    *
    *******************************************************************************/
    void Han_Bus_Slave_Diff_UART_Debug_UartRestoreConfig(void)
    {
    #if (Han_Bus_Slave_Diff_UART_Debug_UART_RX_WAKEUP_IRQ)
        /* Disable interrupt: no more triggers in active mode */
        Han_Bus_Slave_Diff_UART_Debug_RxWakeDisableInt();
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_UART_RX_WAKEUP_IRQ) */
    }


    #if (Han_Bus_Slave_Diff_UART_Debug_UART_RX_WAKEUP_IRQ)
        /*******************************************************************************
        * Function Name: Han_Bus_Slave_Diff_UART_Debug_UART_WAKEUP_ISR
        ****************************************************************************//**
        *
        *  Handles the Interrupt Service Routine for the SCB UART mode GPIO wakeup
        *  event. This event is configured to trigger on a falling edge of the RX line.
        *
        *******************************************************************************/
        CY_ISR(Han_Bus_Slave_Diff_UART_Debug_UART_WAKEUP_ISR)
        {
        #ifdef Han_Bus_Slave_Diff_UART_Debug_UART_WAKEUP_ISR_ENTRY_CALLBACK
            Han_Bus_Slave_Diff_UART_Debug_UART_WAKEUP_ISR_EntryCallback();
        #endif /* Han_Bus_Slave_Diff_UART_Debug_UART_WAKEUP_ISR_ENTRY_CALLBACK */

            Han_Bus_Slave_Diff_UART_Debug_CLEAR_UART_RX_WAKE_INTR;

        #ifdef Han_Bus_Slave_Diff_UART_Debug_UART_WAKEUP_ISR_EXIT_CALLBACK
            Han_Bus_Slave_Diff_UART_Debug_UART_WAKEUP_ISR_ExitCallback();
        #endif /* Han_Bus_Slave_Diff_UART_Debug_UART_WAKEUP_ISR_EXIT_CALLBACK */
        }
    #endif /* (Han_Bus_Slave_Diff_UART_Debug_UART_RX_WAKEUP_IRQ) */
#endif /* (Han_Bus_Slave_Diff_UART_Debug_UART_RX_WAKEUP_IRQ) */


/* [] END OF FILE */
