/*******************************************************************************
* File Name: Han_Bus_Slave_Diff_UART_PM.c
* Version 2.50
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "Han_Bus_Slave_Diff_UART.h"


/***************************************
* Local data allocation
***************************************/

static Han_Bus_Slave_Diff_UART_BACKUP_STRUCT  Han_Bus_Slave_Diff_UART_backup =
{
    /* enableState - disabled */
    0u,
};



/*******************************************************************************
* Function Name: Han_Bus_Slave_Diff_UART_SaveConfig
********************************************************************************
*
* Summary:
*  This function saves the component nonretention control register.
*  Does not save the FIFO which is a set of nonretention registers.
*  This function is called by the Han_Bus_Slave_Diff_UART_Sleep() function.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  Han_Bus_Slave_Diff_UART_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void Han_Bus_Slave_Diff_UART_SaveConfig(void)
{
    #if(Han_Bus_Slave_Diff_UART_CONTROL_REG_REMOVED == 0u)
        Han_Bus_Slave_Diff_UART_backup.cr = Han_Bus_Slave_Diff_UART_CONTROL_REG;
    #endif /* End Han_Bus_Slave_Diff_UART_CONTROL_REG_REMOVED */
}


/*******************************************************************************
* Function Name: Han_Bus_Slave_Diff_UART_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the nonretention control register except FIFO.
*  Does not restore the FIFO which is a set of nonretention registers.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  Han_Bus_Slave_Diff_UART_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
* Notes:
*  If this function is called without calling Han_Bus_Slave_Diff_UART_SaveConfig() 
*  first, the data loaded may be incorrect.
*
*******************************************************************************/
void Han_Bus_Slave_Diff_UART_RestoreConfig(void)
{
    #if(Han_Bus_Slave_Diff_UART_CONTROL_REG_REMOVED == 0u)
        Han_Bus_Slave_Diff_UART_CONTROL_REG = Han_Bus_Slave_Diff_UART_backup.cr;
    #endif /* End Han_Bus_Slave_Diff_UART_CONTROL_REG_REMOVED */
}


/*******************************************************************************
* Function Name: Han_Bus_Slave_Diff_UART_Sleep
********************************************************************************
*
* Summary:
*  This is the preferred API to prepare the component for sleep. 
*  The Han_Bus_Slave_Diff_UART_Sleep() API saves the current component state. Then it
*  calls the Han_Bus_Slave_Diff_UART_Stop() function and calls 
*  Han_Bus_Slave_Diff_UART_SaveConfig() to save the hardware configuration.
*  Call the Han_Bus_Slave_Diff_UART_Sleep() function before calling the CyPmSleep() 
*  or the CyPmHibernate() function. 
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  Han_Bus_Slave_Diff_UART_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void Han_Bus_Slave_Diff_UART_Sleep(void)
{
    #if(Han_Bus_Slave_Diff_UART_RX_ENABLED || Han_Bus_Slave_Diff_UART_HD_ENABLED)
        if((Han_Bus_Slave_Diff_UART_RXSTATUS_ACTL_REG  & Han_Bus_Slave_Diff_UART_INT_ENABLE) != 0u)
        {
            Han_Bus_Slave_Diff_UART_backup.enableState = 1u;
        }
        else
        {
            Han_Bus_Slave_Diff_UART_backup.enableState = 0u;
        }
    #else
        if((Han_Bus_Slave_Diff_UART_TXSTATUS_ACTL_REG  & Han_Bus_Slave_Diff_UART_INT_ENABLE) !=0u)
        {
            Han_Bus_Slave_Diff_UART_backup.enableState = 1u;
        }
        else
        {
            Han_Bus_Slave_Diff_UART_backup.enableState = 0u;
        }
    #endif /* End Han_Bus_Slave_Diff_UART_RX_ENABLED || Han_Bus_Slave_Diff_UART_HD_ENABLED*/

    Han_Bus_Slave_Diff_UART_Stop();
    Han_Bus_Slave_Diff_UART_SaveConfig();
}


/*******************************************************************************
* Function Name: Han_Bus_Slave_Diff_UART_Wakeup
********************************************************************************
*
* Summary:
*  This is the preferred API to restore the component to the state when 
*  Han_Bus_Slave_Diff_UART_Sleep() was called. The Han_Bus_Slave_Diff_UART_Wakeup() function
*  calls the Han_Bus_Slave_Diff_UART_RestoreConfig() function to restore the 
*  configuration. If the component was enabled before the 
*  Han_Bus_Slave_Diff_UART_Sleep() function was called, the Han_Bus_Slave_Diff_UART_Wakeup()
*  function will also re-enable the component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  Han_Bus_Slave_Diff_UART_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void Han_Bus_Slave_Diff_UART_Wakeup(void)
{
    Han_Bus_Slave_Diff_UART_RestoreConfig();
    #if( (Han_Bus_Slave_Diff_UART_RX_ENABLED) || (Han_Bus_Slave_Diff_UART_HD_ENABLED) )
        Han_Bus_Slave_Diff_UART_ClearRxBuffer();
    #endif /* End (Han_Bus_Slave_Diff_UART_RX_ENABLED) || (Han_Bus_Slave_Diff_UART_HD_ENABLED) */
    #if(Han_Bus_Slave_Diff_UART_TX_ENABLED || Han_Bus_Slave_Diff_UART_HD_ENABLED)
        Han_Bus_Slave_Diff_UART_ClearTxBuffer();
    #endif /* End Han_Bus_Slave_Diff_UART_TX_ENABLED || Han_Bus_Slave_Diff_UART_HD_ENABLED */

    if(Han_Bus_Slave_Diff_UART_backup.enableState != 0u)
    {
        Han_Bus_Slave_Diff_UART_Enable();
    }
}


/* [] END OF FILE */
