/*******************************************************************************
* File Name: Port2_Out.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Port2_Out.h"

static Port2_Out_BACKUP_STRUCT  Port2_Out_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: Port2_Out_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function must be called for SIO and USBIO
*  pins. It is not essential if using GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet Port2_Out_SUT.c usage_Port2_Out_Sleep_Wakeup
*******************************************************************************/
void Port2_Out_Sleep(void)
{
    #if defined(Port2_Out__PC)
        Port2_Out_backup.pcState = Port2_Out_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            Port2_Out_backup.usbState = Port2_Out_CR1_REG;
            Port2_Out_USB_POWER_REG |= Port2_Out_USBIO_ENTER_SLEEP;
            Port2_Out_CR1_REG &= Port2_Out_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(Port2_Out__SIO)
        Port2_Out_backup.sioState = Port2_Out_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        Port2_Out_SIO_REG &= (uint32)(~Port2_Out_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: Port2_Out_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep().
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to Port2_Out_Sleep() for an example usage.
*******************************************************************************/
void Port2_Out_Wakeup(void)
{
    #if defined(Port2_Out__PC)
        Port2_Out_PC = Port2_Out_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            Port2_Out_USB_POWER_REG &= Port2_Out_USBIO_EXIT_SLEEP_PH1;
            Port2_Out_CR1_REG = Port2_Out_backup.usbState;
            Port2_Out_USB_POWER_REG &= Port2_Out_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(Port2_Out__SIO)
        Port2_Out_SIO_REG = Port2_Out_backup.sioState;
    #endif
}


/* [] END OF FILE */
