/*******************************************************************************
* File Name: TestComponent_UART.h
* Version 2.50
*
* Description:
*  Contains the function prototypes and constants available to the UART
*  user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/


#if !defined(CY_UART_TestComponent_UART_H)
#define CY_UART_TestComponent_UART_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h"


/***************************************
* Conditional Compilation Parameters
***************************************/

#define TestComponent_UART_RX_ENABLED                     (1u)
#define TestComponent_UART_TX_ENABLED                     (1u)
#define TestComponent_UART_HD_ENABLED                     (0u)
#define TestComponent_UART_RX_INTERRUPT_ENABLED           (0u)
#define TestComponent_UART_TX_INTERRUPT_ENABLED           (0u)
#define TestComponent_UART_INTERNAL_CLOCK_USED            (0u)
#define TestComponent_UART_RXHW_ADDRESS_ENABLED           (0u)
#define TestComponent_UART_OVER_SAMPLE_COUNT              (8u)
#define TestComponent_UART_PARITY_TYPE                    (0u)
#define TestComponent_UART_PARITY_TYPE_SW                 (0u)
#define TestComponent_UART_BREAK_DETECT                   (0u)
#define TestComponent_UART_BREAK_BITS_TX                  (13u)
#define TestComponent_UART_BREAK_BITS_RX                  (13u)
#define TestComponent_UART_TXCLKGEN_DP                    (1u)
#define TestComponent_UART_USE23POLLING                   (0u)
#define TestComponent_UART_FLOW_CONTROL                   (0u)
#define TestComponent_UART_CLK_FREQ                       (0u)
#define TestComponent_UART_TX_BUFFER_SIZE                 (4u)
#define TestComponent_UART_RX_BUFFER_SIZE                 (4u)

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component UART_v2_50 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

#if defined(TestComponent_UART_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG)
    #define TestComponent_UART_CONTROL_REG_REMOVED            (0u)
#else
    #define TestComponent_UART_CONTROL_REG_REMOVED            (1u)
#endif /* End TestComponent_UART_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */


/***************************************
*      Data Structure Definition
***************************************/

/* Sleep Mode API Support */
typedef struct TestComponent_UART_backupStruct_
{
    uint8 enableState;

    #if(TestComponent_UART_CONTROL_REG_REMOVED == 0u)
        uint8 cr;
    #endif /* End TestComponent_UART_CONTROL_REG_REMOVED */

} TestComponent_UART_BACKUP_STRUCT;


/***************************************
*       Function Prototypes
***************************************/

void TestComponent_UART_Start(void) ;
void TestComponent_UART_Stop(void) ;
uint8 TestComponent_UART_ReadControlRegister(void) ;
void TestComponent_UART_WriteControlRegister(uint8 control) ;

void TestComponent_UART_Init(void) ;
void TestComponent_UART_Enable(void) ;
void TestComponent_UART_SaveConfig(void) ;
void TestComponent_UART_RestoreConfig(void) ;
void TestComponent_UART_Sleep(void) ;
void TestComponent_UART_Wakeup(void) ;

/* Only if RX is enabled */
#if( (TestComponent_UART_RX_ENABLED) || (TestComponent_UART_HD_ENABLED) )

    #if (TestComponent_UART_RX_INTERRUPT_ENABLED)
        #define TestComponent_UART_EnableRxInt()  CyIntEnable (TestComponent_UART_RX_VECT_NUM)
        #define TestComponent_UART_DisableRxInt() CyIntDisable(TestComponent_UART_RX_VECT_NUM)
        CY_ISR_PROTO(TestComponent_UART_RXISR);
    #endif /* TestComponent_UART_RX_INTERRUPT_ENABLED */

    void TestComponent_UART_SetRxAddressMode(uint8 addressMode)
                                                           ;
    void TestComponent_UART_SetRxAddress1(uint8 address) ;
    void TestComponent_UART_SetRxAddress2(uint8 address) ;

    void  TestComponent_UART_SetRxInterruptMode(uint8 intSrc) ;
    uint8 TestComponent_UART_ReadRxData(void) ;
    uint8 TestComponent_UART_ReadRxStatus(void) ;
    uint8 TestComponent_UART_GetChar(void) ;
    uint16 TestComponent_UART_GetByte(void) ;
    uint8 TestComponent_UART_GetRxBufferSize(void)
                                                            ;
    void TestComponent_UART_ClearRxBuffer(void) ;

    /* Obsolete functions, defines for backward compatible */
    #define TestComponent_UART_GetRxInterruptSource   TestComponent_UART_ReadRxStatus

#endif /* End (TestComponent_UART_RX_ENABLED) || (TestComponent_UART_HD_ENABLED) */

/* Only if TX is enabled */
#if(TestComponent_UART_TX_ENABLED || TestComponent_UART_HD_ENABLED)

    #if(TestComponent_UART_TX_INTERRUPT_ENABLED)
        #define TestComponent_UART_EnableTxInt()  CyIntEnable (TestComponent_UART_TX_VECT_NUM)
        #define TestComponent_UART_DisableTxInt() CyIntDisable(TestComponent_UART_TX_VECT_NUM)
        #define TestComponent_UART_SetPendingTxInt() CyIntSetPending(TestComponent_UART_TX_VECT_NUM)
        #define TestComponent_UART_ClearPendingTxInt() CyIntClearPending(TestComponent_UART_TX_VECT_NUM)
        CY_ISR_PROTO(TestComponent_UART_TXISR);
    #endif /* TestComponent_UART_TX_INTERRUPT_ENABLED */

    void TestComponent_UART_SetTxInterruptMode(uint8 intSrc) ;
    void TestComponent_UART_WriteTxData(uint8 txDataByte) ;
    uint8 TestComponent_UART_ReadTxStatus(void) ;
    void TestComponent_UART_PutChar(uint8 txDataByte) ;
    void TestComponent_UART_PutString(const char8 string[]) ;
    void TestComponent_UART_PutArray(const uint8 string[], uint8 byteCount)
                                                            ;
    void TestComponent_UART_PutCRLF(uint8 txDataByte) ;
    void TestComponent_UART_ClearTxBuffer(void) ;
    void TestComponent_UART_SetTxAddressMode(uint8 addressMode) ;
    void TestComponent_UART_SendBreak(uint8 retMode) ;
    uint8 TestComponent_UART_GetTxBufferSize(void)
                                                            ;
    /* Obsolete functions, defines for backward compatible */
    #define TestComponent_UART_PutStringConst         TestComponent_UART_PutString
    #define TestComponent_UART_PutArrayConst          TestComponent_UART_PutArray
    #define TestComponent_UART_GetTxInterruptSource   TestComponent_UART_ReadTxStatus

#endif /* End TestComponent_UART_TX_ENABLED || TestComponent_UART_HD_ENABLED */

#if(TestComponent_UART_HD_ENABLED)
    void TestComponent_UART_LoadRxConfig(void) ;
    void TestComponent_UART_LoadTxConfig(void) ;
#endif /* End TestComponent_UART_HD_ENABLED */


/* Communication bootloader APIs */
#if defined(CYDEV_BOOTLOADER_IO_COMP) && ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_TestComponent_UART) || \
                                          (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))
    /* Physical layer functions */
    void    TestComponent_UART_CyBtldrCommStart(void) CYSMALL ;
    void    TestComponent_UART_CyBtldrCommStop(void) CYSMALL ;
    void    TestComponent_UART_CyBtldrCommReset(void) CYSMALL ;
    cystatus TestComponent_UART_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;
    cystatus TestComponent_UART_CyBtldrCommRead(uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;

    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_TestComponent_UART)
        #define CyBtldrCommStart    TestComponent_UART_CyBtldrCommStart
        #define CyBtldrCommStop     TestComponent_UART_CyBtldrCommStop
        #define CyBtldrCommReset    TestComponent_UART_CyBtldrCommReset
        #define CyBtldrCommWrite    TestComponent_UART_CyBtldrCommWrite
        #define CyBtldrCommRead     TestComponent_UART_CyBtldrCommRead
    #endif  /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_TestComponent_UART) */

    /* Byte to Byte time out for detecting end of block data from host */
    #define TestComponent_UART_BYTE2BYTE_TIME_OUT (25u)
    #define TestComponent_UART_PACKET_EOP         (0x17u) /* End of packet defined by bootloader */
    #define TestComponent_UART_WAIT_EOP_DELAY     (5u)    /* Additional 5ms to wait for End of packet */
    #define TestComponent_UART_BL_CHK_DELAY_MS    (1u)    /* Time Out quantity equal 1mS */

#endif /* CYDEV_BOOTLOADER_IO_COMP */


/***************************************
*          API Constants
***************************************/
/* Parameters for SetTxAddressMode API*/
#define TestComponent_UART_SET_SPACE      (0x00u)
#define TestComponent_UART_SET_MARK       (0x01u)

/* Status Register definitions */
#if( (TestComponent_UART_TX_ENABLED) || (TestComponent_UART_HD_ENABLED) )
    #if(TestComponent_UART_TX_INTERRUPT_ENABLED)
        #define TestComponent_UART_TX_VECT_NUM            (uint8)TestComponent_UART_TXInternalInterrupt__INTC_NUMBER
        #define TestComponent_UART_TX_PRIOR_NUM           (uint8)TestComponent_UART_TXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* TestComponent_UART_TX_INTERRUPT_ENABLED */

    #define TestComponent_UART_TX_STS_COMPLETE_SHIFT          (0x00u)
    #define TestComponent_UART_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
    #define TestComponent_UART_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #if(TestComponent_UART_TX_ENABLED)
        #define TestComponent_UART_TX_STS_FIFO_FULL_SHIFT     (0x02u)
    #else /* (TestComponent_UART_HD_ENABLED) */
        #define TestComponent_UART_TX_STS_FIFO_FULL_SHIFT     (0x05u)  /* Needs MD=0 */
    #endif /* (TestComponent_UART_TX_ENABLED) */

    #define TestComponent_UART_TX_STS_COMPLETE            (uint8)(0x01u << TestComponent_UART_TX_STS_COMPLETE_SHIFT)
    #define TestComponent_UART_TX_STS_FIFO_EMPTY          (uint8)(0x01u << TestComponent_UART_TX_STS_FIFO_EMPTY_SHIFT)
    #define TestComponent_UART_TX_STS_FIFO_FULL           (uint8)(0x01u << TestComponent_UART_TX_STS_FIFO_FULL_SHIFT)
    #define TestComponent_UART_TX_STS_FIFO_NOT_FULL       (uint8)(0x01u << TestComponent_UART_TX_STS_FIFO_NOT_FULL_SHIFT)
#endif /* End (TestComponent_UART_TX_ENABLED) || (TestComponent_UART_HD_ENABLED)*/

#if( (TestComponent_UART_RX_ENABLED) || (TestComponent_UART_HD_ENABLED) )
    #if(TestComponent_UART_RX_INTERRUPT_ENABLED)
        #define TestComponent_UART_RX_VECT_NUM            (uint8)TestComponent_UART_RXInternalInterrupt__INTC_NUMBER
        #define TestComponent_UART_RX_PRIOR_NUM           (uint8)TestComponent_UART_RXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* TestComponent_UART_RX_INTERRUPT_ENABLED */
    #define TestComponent_UART_RX_STS_MRKSPC_SHIFT            (0x00u)
    #define TestComponent_UART_RX_STS_BREAK_SHIFT             (0x01u)
    #define TestComponent_UART_RX_STS_PAR_ERROR_SHIFT         (0x02u)
    #define TestComponent_UART_RX_STS_STOP_ERROR_SHIFT        (0x03u)
    #define TestComponent_UART_RX_STS_OVERRUN_SHIFT           (0x04u)
    #define TestComponent_UART_RX_STS_FIFO_NOTEMPTY_SHIFT     (0x05u)
    #define TestComponent_UART_RX_STS_ADDR_MATCH_SHIFT        (0x06u)
    #define TestComponent_UART_RX_STS_SOFT_BUFF_OVER_SHIFT    (0x07u)

    #define TestComponent_UART_RX_STS_MRKSPC           (uint8)(0x01u << TestComponent_UART_RX_STS_MRKSPC_SHIFT)
    #define TestComponent_UART_RX_STS_BREAK            (uint8)(0x01u << TestComponent_UART_RX_STS_BREAK_SHIFT)
    #define TestComponent_UART_RX_STS_PAR_ERROR        (uint8)(0x01u << TestComponent_UART_RX_STS_PAR_ERROR_SHIFT)
    #define TestComponent_UART_RX_STS_STOP_ERROR       (uint8)(0x01u << TestComponent_UART_RX_STS_STOP_ERROR_SHIFT)
    #define TestComponent_UART_RX_STS_OVERRUN          (uint8)(0x01u << TestComponent_UART_RX_STS_OVERRUN_SHIFT)
    #define TestComponent_UART_RX_STS_FIFO_NOTEMPTY    (uint8)(0x01u << TestComponent_UART_RX_STS_FIFO_NOTEMPTY_SHIFT)
    #define TestComponent_UART_RX_STS_ADDR_MATCH       (uint8)(0x01u << TestComponent_UART_RX_STS_ADDR_MATCH_SHIFT)
    #define TestComponent_UART_RX_STS_SOFT_BUFF_OVER   (uint8)(0x01u << TestComponent_UART_RX_STS_SOFT_BUFF_OVER_SHIFT)
    #define TestComponent_UART_RX_HW_MASK                     (0x7Fu)
#endif /* End (TestComponent_UART_RX_ENABLED) || (TestComponent_UART_HD_ENABLED) */

/* Control Register definitions */
#define TestComponent_UART_CTRL_HD_SEND_SHIFT                 (0x00u) /* 1 enable TX part in Half Duplex mode */
#define TestComponent_UART_CTRL_HD_SEND_BREAK_SHIFT           (0x01u) /* 1 send BREAK signal in Half Duplez mode */
#define TestComponent_UART_CTRL_MARK_SHIFT                    (0x02u) /* 1 sets mark, 0 sets space */
#define TestComponent_UART_CTRL_PARITY_TYPE0_SHIFT            (0x03u) /* Defines the type of parity implemented */
#define TestComponent_UART_CTRL_PARITY_TYPE1_SHIFT            (0x04u) /* Defines the type of parity implemented */
#define TestComponent_UART_CTRL_RXADDR_MODE0_SHIFT            (0x05u)
#define TestComponent_UART_CTRL_RXADDR_MODE1_SHIFT            (0x06u)
#define TestComponent_UART_CTRL_RXADDR_MODE2_SHIFT            (0x07u)

#define TestComponent_UART_CTRL_HD_SEND               (uint8)(0x01u << TestComponent_UART_CTRL_HD_SEND_SHIFT)
#define TestComponent_UART_CTRL_HD_SEND_BREAK         (uint8)(0x01u << TestComponent_UART_CTRL_HD_SEND_BREAK_SHIFT)
#define TestComponent_UART_CTRL_MARK                  (uint8)(0x01u << TestComponent_UART_CTRL_MARK_SHIFT)
#define TestComponent_UART_CTRL_PARITY_TYPE_MASK      (uint8)(0x03u << TestComponent_UART_CTRL_PARITY_TYPE0_SHIFT)
#define TestComponent_UART_CTRL_RXADDR_MODE_MASK      (uint8)(0x07u << TestComponent_UART_CTRL_RXADDR_MODE0_SHIFT)

/* StatusI Register Interrupt Enable Control Bits. As defined by the Register map for the AUX Control Register */
#define TestComponent_UART_INT_ENABLE                         (0x10u)

/* Bit Counter (7-bit) Control Register Bit Definitions. As defined by the Register map for the AUX Control Register */
#define TestComponent_UART_CNTR_ENABLE                        (0x20u)

/*   Constants for SendBreak() "retMode" parameter  */
#define TestComponent_UART_SEND_BREAK                         (0x00u)
#define TestComponent_UART_WAIT_FOR_COMPLETE_REINIT           (0x01u)
#define TestComponent_UART_REINIT                             (0x02u)
#define TestComponent_UART_SEND_WAIT_REINIT                   (0x03u)

#define TestComponent_UART_OVER_SAMPLE_8                      (8u)
#define TestComponent_UART_OVER_SAMPLE_16                     (16u)

#define TestComponent_UART_BIT_CENTER                         (TestComponent_UART_OVER_SAMPLE_COUNT - 2u)

#define TestComponent_UART_FIFO_LENGTH                        (4u)
#define TestComponent_UART_NUMBER_OF_START_BIT                (1u)
#define TestComponent_UART_MAX_BYTE_VALUE                     (0xFFu)

/* 8X always for count7 implementation */
#define TestComponent_UART_TXBITCTR_BREAKBITS8X   ((TestComponent_UART_BREAK_BITS_TX * TestComponent_UART_OVER_SAMPLE_8) - 1u)
/* 8X or 16X for DP implementation */
#define TestComponent_UART_TXBITCTR_BREAKBITS ((TestComponent_UART_BREAK_BITS_TX * TestComponent_UART_OVER_SAMPLE_COUNT) - 1u)

#define TestComponent_UART_HALF_BIT_COUNT   \
                            (((TestComponent_UART_OVER_SAMPLE_COUNT / 2u) + (TestComponent_UART_USE23POLLING * 1u)) - 2u)
#if (TestComponent_UART_OVER_SAMPLE_COUNT == TestComponent_UART_OVER_SAMPLE_8)
    #define TestComponent_UART_HD_TXBITCTR_INIT   (((TestComponent_UART_BREAK_BITS_TX + \
                            TestComponent_UART_NUMBER_OF_START_BIT) * TestComponent_UART_OVER_SAMPLE_COUNT) - 1u)

    /* This parameter is increased on the 2 in 2 out of 3 mode to sample voting in the middle */
    #define TestComponent_UART_RXBITCTR_INIT  ((((TestComponent_UART_BREAK_BITS_RX + TestComponent_UART_NUMBER_OF_START_BIT) \
                            * TestComponent_UART_OVER_SAMPLE_COUNT) + TestComponent_UART_HALF_BIT_COUNT) - 1u)

#else /* TestComponent_UART_OVER_SAMPLE_COUNT == TestComponent_UART_OVER_SAMPLE_16 */
    #define TestComponent_UART_HD_TXBITCTR_INIT   ((8u * TestComponent_UART_OVER_SAMPLE_COUNT) - 1u)
    /* 7bit counter need one more bit for OverSampleCount = 16 */
    #define TestComponent_UART_RXBITCTR_INIT      (((7u * TestComponent_UART_OVER_SAMPLE_COUNT) - 1u) + \
                                                      TestComponent_UART_HALF_BIT_COUNT)
#endif /* End TestComponent_UART_OVER_SAMPLE_COUNT */

#define TestComponent_UART_HD_RXBITCTR_INIT                   TestComponent_UART_RXBITCTR_INIT


/***************************************
* Global variables external identifier
***************************************/

extern uint8 TestComponent_UART_initVar;
#if (TestComponent_UART_TX_INTERRUPT_ENABLED && TestComponent_UART_TX_ENABLED)
    extern volatile uint8 TestComponent_UART_txBuffer[TestComponent_UART_TX_BUFFER_SIZE];
    extern volatile uint8 TestComponent_UART_txBufferRead;
    extern uint8 TestComponent_UART_txBufferWrite;
#endif /* (TestComponent_UART_TX_INTERRUPT_ENABLED && TestComponent_UART_TX_ENABLED) */
#if (TestComponent_UART_RX_INTERRUPT_ENABLED && (TestComponent_UART_RX_ENABLED || TestComponent_UART_HD_ENABLED))
    extern uint8 TestComponent_UART_errorStatus;
    extern volatile uint8 TestComponent_UART_rxBuffer[TestComponent_UART_RX_BUFFER_SIZE];
    extern volatile uint8 TestComponent_UART_rxBufferRead;
    extern volatile uint8 TestComponent_UART_rxBufferWrite;
    extern volatile uint8 TestComponent_UART_rxBufferLoopDetect;
    extern volatile uint8 TestComponent_UART_rxBufferOverflow;
    #if (TestComponent_UART_RXHW_ADDRESS_ENABLED)
        extern volatile uint8 TestComponent_UART_rxAddressMode;
        extern volatile uint8 TestComponent_UART_rxAddressDetected;
    #endif /* (TestComponent_UART_RXHW_ADDRESS_ENABLED) */
#endif /* (TestComponent_UART_RX_INTERRUPT_ENABLED && (TestComponent_UART_RX_ENABLED || TestComponent_UART_HD_ENABLED)) */


/***************************************
* Enumerated Types and Parameters
***************************************/

#define TestComponent_UART__B_UART__AM_SW_BYTE_BYTE 1
#define TestComponent_UART__B_UART__AM_SW_DETECT_TO_BUFFER 2
#define TestComponent_UART__B_UART__AM_HW_BYTE_BY_BYTE 3
#define TestComponent_UART__B_UART__AM_HW_DETECT_TO_BUFFER 4
#define TestComponent_UART__B_UART__AM_NONE 0

#define TestComponent_UART__B_UART__NONE_REVB 0
#define TestComponent_UART__B_UART__EVEN_REVB 1
#define TestComponent_UART__B_UART__ODD_REVB 2
#define TestComponent_UART__B_UART__MARK_SPACE_REVB 3



/***************************************
*    Initial Parameter Constants
***************************************/

/* UART shifts max 8 bits, Mark/Space functionality working if 9 selected */
#define TestComponent_UART_NUMBER_OF_DATA_BITS    ((8u > 8u) ? 8u : 8u)
#define TestComponent_UART_NUMBER_OF_STOP_BITS    (1u)

#if (TestComponent_UART_RXHW_ADDRESS_ENABLED)
    #define TestComponent_UART_RX_ADDRESS_MODE    (0u)
    #define TestComponent_UART_RX_HW_ADDRESS1     (0u)
    #define TestComponent_UART_RX_HW_ADDRESS2     (1u)
#endif /* (TestComponent_UART_RXHW_ADDRESS_ENABLED) */

#define TestComponent_UART_INIT_RX_INTERRUPTS_MASK \
                                  (uint8)((1 << TestComponent_UART_RX_STS_FIFO_NOTEMPTY_SHIFT) \
                                        | (0 << TestComponent_UART_RX_STS_MRKSPC_SHIFT) \
                                        | (0 << TestComponent_UART_RX_STS_ADDR_MATCH_SHIFT) \
                                        | (0 << TestComponent_UART_RX_STS_PAR_ERROR_SHIFT) \
                                        | (0 << TestComponent_UART_RX_STS_STOP_ERROR_SHIFT) \
                                        | (0 << TestComponent_UART_RX_STS_BREAK_SHIFT) \
                                        | (0 << TestComponent_UART_RX_STS_OVERRUN_SHIFT))

#define TestComponent_UART_INIT_TX_INTERRUPTS_MASK \
                                  (uint8)((0 << TestComponent_UART_TX_STS_COMPLETE_SHIFT) \
                                        | (1 << TestComponent_UART_TX_STS_FIFO_EMPTY_SHIFT) \
                                        | (0 << TestComponent_UART_TX_STS_FIFO_FULL_SHIFT) \
                                        | (0 << TestComponent_UART_TX_STS_FIFO_NOT_FULL_SHIFT))


/***************************************
*              Registers
***************************************/

#ifdef TestComponent_UART_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define TestComponent_UART_CONTROL_REG \
                            (* (reg8 *) TestComponent_UART_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG )
    #define TestComponent_UART_CONTROL_PTR \
                            (  (reg8 *) TestComponent_UART_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG )
#endif /* End TestComponent_UART_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */

#if(TestComponent_UART_TX_ENABLED)
    #define TestComponent_UART_TXDATA_REG          (* (reg8 *) TestComponent_UART_BUART_sTX_TxShifter_u0__F0_REG)
    #define TestComponent_UART_TXDATA_PTR          (  (reg8 *) TestComponent_UART_BUART_sTX_TxShifter_u0__F0_REG)
    #define TestComponent_UART_TXDATA_AUX_CTL_REG  (* (reg8 *) TestComponent_UART_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define TestComponent_UART_TXDATA_AUX_CTL_PTR  (  (reg8 *) TestComponent_UART_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define TestComponent_UART_TXSTATUS_REG        (* (reg8 *) TestComponent_UART_BUART_sTX_TxSts__STATUS_REG)
    #define TestComponent_UART_TXSTATUS_PTR        (  (reg8 *) TestComponent_UART_BUART_sTX_TxSts__STATUS_REG)
    #define TestComponent_UART_TXSTATUS_MASK_REG   (* (reg8 *) TestComponent_UART_BUART_sTX_TxSts__MASK_REG)
    #define TestComponent_UART_TXSTATUS_MASK_PTR   (  (reg8 *) TestComponent_UART_BUART_sTX_TxSts__MASK_REG)
    #define TestComponent_UART_TXSTATUS_ACTL_REG   (* (reg8 *) TestComponent_UART_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)
    #define TestComponent_UART_TXSTATUS_ACTL_PTR   (  (reg8 *) TestComponent_UART_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)

    /* DP clock */
    #if(TestComponent_UART_TXCLKGEN_DP)
        #define TestComponent_UART_TXBITCLKGEN_CTR_REG        \
                                        (* (reg8 *) TestComponent_UART_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define TestComponent_UART_TXBITCLKGEN_CTR_PTR        \
                                        (  (reg8 *) TestComponent_UART_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define TestComponent_UART_TXBITCLKTX_COMPLETE_REG    \
                                        (* (reg8 *) TestComponent_UART_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
        #define TestComponent_UART_TXBITCLKTX_COMPLETE_PTR    \
                                        (  (reg8 *) TestComponent_UART_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
    #else     /* Count7 clock*/
        #define TestComponent_UART_TXBITCTR_PERIOD_REG    \
                                        (* (reg8 *) TestComponent_UART_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define TestComponent_UART_TXBITCTR_PERIOD_PTR    \
                                        (  (reg8 *) TestComponent_UART_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define TestComponent_UART_TXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) TestComponent_UART_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define TestComponent_UART_TXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) TestComponent_UART_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define TestComponent_UART_TXBITCTR_COUNTER_REG   \
                                        (* (reg8 *) TestComponent_UART_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
        #define TestComponent_UART_TXBITCTR_COUNTER_PTR   \
                                        (  (reg8 *) TestComponent_UART_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
    #endif /* TestComponent_UART_TXCLKGEN_DP */

#endif /* End TestComponent_UART_TX_ENABLED */

#if(TestComponent_UART_HD_ENABLED)

    #define TestComponent_UART_TXDATA_REG             (* (reg8 *) TestComponent_UART_BUART_sRX_RxShifter_u0__F1_REG )
    #define TestComponent_UART_TXDATA_PTR             (  (reg8 *) TestComponent_UART_BUART_sRX_RxShifter_u0__F1_REG )
    #define TestComponent_UART_TXDATA_AUX_CTL_REG     (* (reg8 *) TestComponent_UART_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)
    #define TestComponent_UART_TXDATA_AUX_CTL_PTR     (  (reg8 *) TestComponent_UART_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define TestComponent_UART_TXSTATUS_REG           (* (reg8 *) TestComponent_UART_BUART_sRX_RxSts__STATUS_REG )
    #define TestComponent_UART_TXSTATUS_PTR           (  (reg8 *) TestComponent_UART_BUART_sRX_RxSts__STATUS_REG )
    #define TestComponent_UART_TXSTATUS_MASK_REG      (* (reg8 *) TestComponent_UART_BUART_sRX_RxSts__MASK_REG )
    #define TestComponent_UART_TXSTATUS_MASK_PTR      (  (reg8 *) TestComponent_UART_BUART_sRX_RxSts__MASK_REG )
    #define TestComponent_UART_TXSTATUS_ACTL_REG      (* (reg8 *) TestComponent_UART_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define TestComponent_UART_TXSTATUS_ACTL_PTR      (  (reg8 *) TestComponent_UART_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End TestComponent_UART_HD_ENABLED */

#if( (TestComponent_UART_RX_ENABLED) || (TestComponent_UART_HD_ENABLED) )
    #define TestComponent_UART_RXDATA_REG             (* (reg8 *) TestComponent_UART_BUART_sRX_RxShifter_u0__F0_REG )
    #define TestComponent_UART_RXDATA_PTR             (  (reg8 *) TestComponent_UART_BUART_sRX_RxShifter_u0__F0_REG )
    #define TestComponent_UART_RXADDRESS1_REG         (* (reg8 *) TestComponent_UART_BUART_sRX_RxShifter_u0__D0_REG )
    #define TestComponent_UART_RXADDRESS1_PTR         (  (reg8 *) TestComponent_UART_BUART_sRX_RxShifter_u0__D0_REG )
    #define TestComponent_UART_RXADDRESS2_REG         (* (reg8 *) TestComponent_UART_BUART_sRX_RxShifter_u0__D1_REG )
    #define TestComponent_UART_RXADDRESS2_PTR         (  (reg8 *) TestComponent_UART_BUART_sRX_RxShifter_u0__D1_REG )
    #define TestComponent_UART_RXDATA_AUX_CTL_REG     (* (reg8 *) TestComponent_UART_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define TestComponent_UART_RXBITCTR_PERIOD_REG    (* (reg8 *) TestComponent_UART_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define TestComponent_UART_RXBITCTR_PERIOD_PTR    (  (reg8 *) TestComponent_UART_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define TestComponent_UART_RXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) TestComponent_UART_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define TestComponent_UART_RXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) TestComponent_UART_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define TestComponent_UART_RXBITCTR_COUNTER_REG   (* (reg8 *) TestComponent_UART_BUART_sRX_RxBitCounter__COUNT_REG )
    #define TestComponent_UART_RXBITCTR_COUNTER_PTR   (  (reg8 *) TestComponent_UART_BUART_sRX_RxBitCounter__COUNT_REG )

    #define TestComponent_UART_RXSTATUS_REG           (* (reg8 *) TestComponent_UART_BUART_sRX_RxSts__STATUS_REG )
    #define TestComponent_UART_RXSTATUS_PTR           (  (reg8 *) TestComponent_UART_BUART_sRX_RxSts__STATUS_REG )
    #define TestComponent_UART_RXSTATUS_MASK_REG      (* (reg8 *) TestComponent_UART_BUART_sRX_RxSts__MASK_REG )
    #define TestComponent_UART_RXSTATUS_MASK_PTR      (  (reg8 *) TestComponent_UART_BUART_sRX_RxSts__MASK_REG )
    #define TestComponent_UART_RXSTATUS_ACTL_REG      (* (reg8 *) TestComponent_UART_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define TestComponent_UART_RXSTATUS_ACTL_PTR      (  (reg8 *) TestComponent_UART_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End  (TestComponent_UART_RX_ENABLED) || (TestComponent_UART_HD_ENABLED) */

#if(TestComponent_UART_INTERNAL_CLOCK_USED)
    /* Register to enable or disable the digital clocks */
    #define TestComponent_UART_INTCLOCK_CLKEN_REG     (* (reg8 *) TestComponent_UART_IntClock__PM_ACT_CFG)
    #define TestComponent_UART_INTCLOCK_CLKEN_PTR     (  (reg8 *) TestComponent_UART_IntClock__PM_ACT_CFG)

    /* Clock mask for this clock. */
    #define TestComponent_UART_INTCLOCK_CLKEN_MASK    TestComponent_UART_IntClock__PM_ACT_MSK
#endif /* End TestComponent_UART_INTERNAL_CLOCK_USED */


/***************************************
*       Register Constants
***************************************/

#if(TestComponent_UART_TX_ENABLED)
    #define TestComponent_UART_TX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End TestComponent_UART_TX_ENABLED */

#if(TestComponent_UART_HD_ENABLED)
    #define TestComponent_UART_TX_FIFO_CLR            (0x02u) /* FIFO1 CLR */
#endif /* End TestComponent_UART_HD_ENABLED */

#if( (TestComponent_UART_RX_ENABLED) || (TestComponent_UART_HD_ENABLED) )
    #define TestComponent_UART_RX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End  (TestComponent_UART_RX_ENABLED) || (TestComponent_UART_HD_ENABLED) */


/***************************************
* The following code is DEPRECATED and
* should not be used in new projects.
***************************************/

/* UART v2_40 obsolete definitions */
#define TestComponent_UART_WAIT_1_MS      TestComponent_UART_BL_CHK_DELAY_MS   

#define TestComponent_UART_TXBUFFERSIZE   TestComponent_UART_TX_BUFFER_SIZE
#define TestComponent_UART_RXBUFFERSIZE   TestComponent_UART_RX_BUFFER_SIZE

#if (TestComponent_UART_RXHW_ADDRESS_ENABLED)
    #define TestComponent_UART_RXADDRESSMODE  TestComponent_UART_RX_ADDRESS_MODE
    #define TestComponent_UART_RXHWADDRESS1   TestComponent_UART_RX_HW_ADDRESS1
    #define TestComponent_UART_RXHWADDRESS2   TestComponent_UART_RX_HW_ADDRESS2
    /* Backward compatible define */
    #define TestComponent_UART_RXAddressMode  TestComponent_UART_RXADDRESSMODE
#endif /* (TestComponent_UART_RXHW_ADDRESS_ENABLED) */

/* UART v2_30 obsolete definitions */
#define TestComponent_UART_initvar                    TestComponent_UART_initVar

#define TestComponent_UART_RX_Enabled                 TestComponent_UART_RX_ENABLED
#define TestComponent_UART_TX_Enabled                 TestComponent_UART_TX_ENABLED
#define TestComponent_UART_HD_Enabled                 TestComponent_UART_HD_ENABLED
#define TestComponent_UART_RX_IntInterruptEnabled     TestComponent_UART_RX_INTERRUPT_ENABLED
#define TestComponent_UART_TX_IntInterruptEnabled     TestComponent_UART_TX_INTERRUPT_ENABLED
#define TestComponent_UART_InternalClockUsed          TestComponent_UART_INTERNAL_CLOCK_USED
#define TestComponent_UART_RXHW_Address_Enabled       TestComponent_UART_RXHW_ADDRESS_ENABLED
#define TestComponent_UART_OverSampleCount            TestComponent_UART_OVER_SAMPLE_COUNT
#define TestComponent_UART_ParityType                 TestComponent_UART_PARITY_TYPE

#if( TestComponent_UART_TX_ENABLED && (TestComponent_UART_TXBUFFERSIZE > TestComponent_UART_FIFO_LENGTH))
    #define TestComponent_UART_TXBUFFER               TestComponent_UART_txBuffer
    #define TestComponent_UART_TXBUFFERREAD           TestComponent_UART_txBufferRead
    #define TestComponent_UART_TXBUFFERWRITE          TestComponent_UART_txBufferWrite
#endif /* End TestComponent_UART_TX_ENABLED */
#if( ( TestComponent_UART_RX_ENABLED || TestComponent_UART_HD_ENABLED ) && \
     (TestComponent_UART_RXBUFFERSIZE > TestComponent_UART_FIFO_LENGTH) )
    #define TestComponent_UART_RXBUFFER               TestComponent_UART_rxBuffer
    #define TestComponent_UART_RXBUFFERREAD           TestComponent_UART_rxBufferRead
    #define TestComponent_UART_RXBUFFERWRITE          TestComponent_UART_rxBufferWrite
    #define TestComponent_UART_RXBUFFERLOOPDETECT     TestComponent_UART_rxBufferLoopDetect
    #define TestComponent_UART_RXBUFFER_OVERFLOW      TestComponent_UART_rxBufferOverflow
#endif /* End TestComponent_UART_RX_ENABLED */

#ifdef TestComponent_UART_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define TestComponent_UART_CONTROL                TestComponent_UART_CONTROL_REG
#endif /* End TestComponent_UART_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */

#if(TestComponent_UART_TX_ENABLED)
    #define TestComponent_UART_TXDATA                 TestComponent_UART_TXDATA_REG
    #define TestComponent_UART_TXSTATUS               TestComponent_UART_TXSTATUS_REG
    #define TestComponent_UART_TXSTATUS_MASK          TestComponent_UART_TXSTATUS_MASK_REG
    #define TestComponent_UART_TXSTATUS_ACTL          TestComponent_UART_TXSTATUS_ACTL_REG
    /* DP clock */
    #if(TestComponent_UART_TXCLKGEN_DP)
        #define TestComponent_UART_TXBITCLKGEN_CTR        TestComponent_UART_TXBITCLKGEN_CTR_REG
        #define TestComponent_UART_TXBITCLKTX_COMPLETE    TestComponent_UART_TXBITCLKTX_COMPLETE_REG
    #else     /* Count7 clock*/
        #define TestComponent_UART_TXBITCTR_PERIOD        TestComponent_UART_TXBITCTR_PERIOD_REG
        #define TestComponent_UART_TXBITCTR_CONTROL       TestComponent_UART_TXBITCTR_CONTROL_REG
        #define TestComponent_UART_TXBITCTR_COUNTER       TestComponent_UART_TXBITCTR_COUNTER_REG
    #endif /* TestComponent_UART_TXCLKGEN_DP */
#endif /* End TestComponent_UART_TX_ENABLED */

#if(TestComponent_UART_HD_ENABLED)
    #define TestComponent_UART_TXDATA                 TestComponent_UART_TXDATA_REG
    #define TestComponent_UART_TXSTATUS               TestComponent_UART_TXSTATUS_REG
    #define TestComponent_UART_TXSTATUS_MASK          TestComponent_UART_TXSTATUS_MASK_REG
    #define TestComponent_UART_TXSTATUS_ACTL          TestComponent_UART_TXSTATUS_ACTL_REG
#endif /* End TestComponent_UART_HD_ENABLED */

#if( (TestComponent_UART_RX_ENABLED) || (TestComponent_UART_HD_ENABLED) )
    #define TestComponent_UART_RXDATA                 TestComponent_UART_RXDATA_REG
    #define TestComponent_UART_RXADDRESS1             TestComponent_UART_RXADDRESS1_REG
    #define TestComponent_UART_RXADDRESS2             TestComponent_UART_RXADDRESS2_REG
    #define TestComponent_UART_RXBITCTR_PERIOD        TestComponent_UART_RXBITCTR_PERIOD_REG
    #define TestComponent_UART_RXBITCTR_CONTROL       TestComponent_UART_RXBITCTR_CONTROL_REG
    #define TestComponent_UART_RXBITCTR_COUNTER       TestComponent_UART_RXBITCTR_COUNTER_REG
    #define TestComponent_UART_RXSTATUS               TestComponent_UART_RXSTATUS_REG
    #define TestComponent_UART_RXSTATUS_MASK          TestComponent_UART_RXSTATUS_MASK_REG
    #define TestComponent_UART_RXSTATUS_ACTL          TestComponent_UART_RXSTATUS_ACTL_REG
#endif /* End  (TestComponent_UART_RX_ENABLED) || (TestComponent_UART_HD_ENABLED) */

#if(TestComponent_UART_INTERNAL_CLOCK_USED)
    #define TestComponent_UART_INTCLOCK_CLKEN         TestComponent_UART_INTCLOCK_CLKEN_REG
#endif /* End TestComponent_UART_INTERNAL_CLOCK_USED */

#define TestComponent_UART_WAIT_FOR_COMLETE_REINIT    TestComponent_UART_WAIT_FOR_COMPLETE_REINIT

#endif  /* CY_UART_TestComponent_UART_H */


/* [] END OF FILE */
