/*******************************************************************************
* File Name: RX_P.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "RX_P.h"

static RX_P_BACKUP_STRUCT  RX_P_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: RX_P_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function must be called for SIO and USBIO
*  pins. It is not essential if using GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet RX_P_SUT.c usage_RX_P_Sleep_Wakeup
*******************************************************************************/
void RX_P_Sleep(void)
{
    #if defined(RX_P__PC)
        RX_P_backup.pcState = RX_P_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            RX_P_backup.usbState = RX_P_CR1_REG;
            RX_P_USB_POWER_REG |= RX_P_USBIO_ENTER_SLEEP;
            RX_P_CR1_REG &= RX_P_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(RX_P__SIO)
        RX_P_backup.sioState = RX_P_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        RX_P_SIO_REG &= (uint32)(~RX_P_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: RX_P_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep().
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to RX_P_Sleep() for an example usage.
*******************************************************************************/
void RX_P_Wakeup(void)
{
    #if defined(RX_P__PC)
        RX_P_PC = RX_P_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            RX_P_USB_POWER_REG &= RX_P_USBIO_EXIT_SLEEP_PH1;
            RX_P_CR1_REG = RX_P_backup.usbState;
            RX_P_USB_POWER_REG &= RX_P_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(RX_P__SIO)
        RX_P_SIO_REG = RX_P_backup.sioState;
    #endif
}


/* [] END OF FILE */
